@@ -28,7 +28,7 @@ import copy
 from PyQt5 import QtWidgets, QtCore
 import numpy as np
 import sklearn.cluster as skc
-import sklearn.metrics as skm
+from sklearn.metrics import calinski_harabasz_score
 import sklearn.preprocessing as skp
 from pygmi.raster.datatypes import Data
 import pygmi.menu_default as menu_default
@@ -51,6 +51,11 @@ class Cluster(QtWidgets.QDialog):
     def __init__(self, parent=None):
         super().__init__(parent)
 
+        if parent is None:
+            self.showprocesslog = print
+        else:
+            self.showprocesslog = parent.showprocesslog
+
         self.indata = {}
         self.outdata = {}
         self.parent = parent
@@ -232,8 +237,8 @@ class Cluster(QtWidgets.QDialog):
         tst = np.unique([i.data.shape for i in self.indata['Raster']])
 
         if tst.size > 2:
-            print('Error: Your input datasets have different sizes. '
-                  'Merge the data first')
+            self.showprocesslog('Error: Your input datasets have different '
+                                'sizes. Merge the data first')
             return False
 
         self.min_samples = len(self.indata['Raster'])+1
@@ -338,7 +343,7 @@ class Cluster(QtWidgets.QDialog):
 
         no_clust = range(self.min_cluster, self.max_cluster+1)
 
-        print('Cluster analysis started')
+        self.showprocesslog('Cluster analysis started')
 
 # Section to deal with different bands having different null values.
         masktmp = data[0].data.mask
@@ -357,7 +362,7 @@ class Cluster(QtWidgets.QDialog):
         dat_out = []
         for i in self.piter(no_clust):
             if self.cltype != 'DBSCAN':
-                print('Number of Clusters:'+str(i))
+                self.showprocesslog('Number of Clusters:'+str(i))
             elif i > no_clust[0]:
                 continue
 
@@ -375,9 +380,9 @@ class Cluster(QtWidgets.QDialog):
                                  branching_factor=self.branchfac).fit(X)
 
             if cfit.labels_.max() < i-1 and self.cltype != 'DBSCAN':
-                print('Could not find '+str(i)+' clusters. '
-                      'Please change settings.')
-                breakpoint()
+                self.showprocesslog('Could not find '+str(i)+' clusters. '
+                                    'Please change settings.')
+
                 return False
 
             dat_out.append(Data())
@@ -396,7 +401,7 @@ class Cluster(QtWidgets.QDialog):
             dat_out[-1].metadata['Cluster']['center'] = np.zeros([i, len(data)])
             dat_out[-1].metadata['Cluster']['center_std'] = np.zeros([i, len(data)])
             if cfit.labels_.max() > 0:
-                dat_out[-1].metadata['Cluster']['vrc'] = skm.calinski_harabasz_score(X, cfit.labels_)
+                dat_out[-1].metadata['Cluster']['vrc'] = calinski_harabasz_score(X, cfit.labels_)
 
             m = []
             s = []
@@ -418,7 +423,7 @@ class Cluster(QtWidgets.QDialog):
             i.nullvalue = data[0].nullvalue
             i.extent = data[0].extent
 
-        print('Cluster complete' + ' ('+self.cltype + ' ' + ')')
+        self.showprocesslog('Cluster complete' + ' ('+self.cltype + ' ' + ')')
 
         for i in dat_out:
             i.data += 1
