@@ -49,6 +49,10 @@ class FuzzyClust(QtWidgets.QDialog):
 
     def __init__(self, parent=None):
         super().__init__(parent)
+        if parent is None:
+            self.showprocesslog = print
+        else:
+            self.showprocesslog = parent.showprocesslog
 
         self.indata = {}
         self.outdata = {}
@@ -138,9 +142,11 @@ class FuzzyClust(QtWidgets.QDialog):
         label_2.setText('Minimum Clusters:')
         label_3.setText('Maximum Clusters')
         label_4.setText('Maximum Iterations:')
-        label_5.setText('Terminate if relative change per iteration is less than:')
+        label_5.setText('Terminate if relative change per iteration is less '
+                        'than:')
         label_6.setText('Repeated Runs:')
-        self.label_7.setText('Constrain Cluster Shape (0: unconstrained, 1: spherical)')
+        self.label_7.setText('Constrain Cluster Shape (0: unconstrained, '
+                             '1: spherical)')
         label_8.setText('Fuzzyness Exponent')
         self.radiobutton_random.setText('Random')
         self.radiobutton_manual.setText('Manual')
@@ -202,8 +208,8 @@ class FuzzyClust(QtWidgets.QDialog):
         """
         tst = np.unique([i.data.shape for i in self.indata['Raster']])
         if tst.size > 2:
-            print('Error: Your input datasets have different sizes. '
-                  'Merge the data first')
+            self.showprocesslog('Error: Your input datasets have different '
+                                'sizes. Merge the data first')
             return False
 
         if not nodialog:
@@ -313,7 +319,7 @@ class FuzzyClust(QtWidgets.QDialog):
         de_norm = self.denorm
         expo = self.fexp
 
-        print('Fuzzy Clustering started')
+        self.showprocesslog('Fuzzy Clustering started')
 
 # #############################################################################
 # Section to deal with different bands having different null values.
@@ -386,10 +392,10 @@ class FuzzyClust(QtWidgets.QDialog):
         dat_out = [Data() for i in range(no_clust[0], no_clust[1] + 1)]
 
         for i in range(no_clust[0], no_clust[1] + 1):
-            print('Number of Clusters:' + str(i))
+            self.showprocesslog('Number of Clusters:' + str(i))
             cnt = cnt + 1
             if self.radiobutton_datadriven.isChecked() is True:
-                print('Initial guess: data driven')
+                self.showprocesslog('Initial guess: data driven')
 
                 no_samp = dat_in.shape[0]
                 dno_samp = no_samp / i
@@ -412,18 +418,19 @@ class FuzzyClust(QtWidgets.QDialog):
                     term_thresh, expo, cltype, cov_constr)
 
             elif self.radiobutton_manual.isChecked() is True:
-                print('Initial guess: manual')
+                self.showprocesslog('Initial guess: manual')
 
                 clu, clcent, clobj_fcn, clvrc, clnce, clxbi = self.fuzzy_means(
                     dat_in, i, startmdat[i], startmfix[i],
                     max_iter, term_thresh, expo, cltype, cov_constr)
 
             elif self.radiobutton_random.isChecked() is True:
-                print('Initial guess: random')
+                self.showprocesslog('Initial guess: random')
 
                 clobj_fcn = np.array([np.Inf])
                 for j in range(no_runs):
-                    print('Run ' + str(j+1) + ' of' + str(no_runs))
+                    self.showprocesslog('Run ' + str(j+1) + ' of' +
+                                        str(no_runs))
 
                     xmins = np.minimum(dat_in, 1)
                     xmaxs = np.maximum(dat_in, 1)
@@ -521,8 +528,8 @@ class FuzzyClust(QtWidgets.QDialog):
             i.extent = data[0].extent
             i.data += 1
 
-        print('Fuzzy Cluster complete' + ' (' + self.cltype + ' ' +
-              self.init_type + ')')
+        self.showprocesslog('Fuzzy Cluster complete' + ' (' + self.cltype +
+                            ' ' + self.init_type + ')')
 
         self.outdata['Cluster'] = dat_out
         self.outdata['Raster'] = self.indata['Raster']
@@ -570,8 +577,8 @@ class FuzzyClust(QtWidgets.QDialog):
             COV_CONSTR applies only to the GK algorithm. constrains the cluster
             shape towards spherical clusters to avoid needle-like clusters.
             COV_CONSTR = 1 make the GK algorithm equal to the FCM algorithm,
-            COV_CONSTR = 0 results in no constraining of the covarince matrices of
-            the clusters.
+            COV_CONSTR = 0 results in no constraining of the covarince matrices
+            of the clusters.
 
         Returns
         -------
@@ -592,7 +599,7 @@ class FuzzyClust(QtWidgets.QDialog):
         xbi : numpy array
             Xie beni index.
         """
-        print(' ')
+        self.showprocesslog(' ')
 
         if cltype == 'fuzzy c-means':
             cltype = 'fcm'
@@ -645,7 +652,7 @@ class FuzzyClust(QtWidgets.QDialog):
     # if membership matrix is provided
         elif init.shape[0] == no_clust and init.shape[1] == no_samples:
             if init[init < 0].size > 0:  # check for negative memberships
-                print('No negative memberships allowed!')
+                self.showprocesslog('No negative memberships allowed!')
     # scale given memberships to a column sum of unity
             uuu = init / (np.ones([no_clust, 1]) * init.sum())
     # MF matrix after exponential modification
@@ -686,11 +693,12 @@ class FuzzyClust(QtWidgets.QDialog):
             m_f = uuu ** expo
             obj_fcn[i] = np.sum((edist ** 2) * m_f)  # objective function
             if i > 0:
-                print('Iteration: ' + str(i) + ' Threshold: ' +
-                      str(term_thresh) + ' Current: ' +
-                      '{:.2e}'.format(100 * ((obj_fcn[i - 1] -
-                                              obj_fcn[i]) /
-                                             obj_fcn[i - 1])), True)
+                self.showprocesslog('Iteration: ' + str(i) + ' Threshold: ' +
+                                    str(term_thresh) + ' Current: ' +
+                                    '{:.2e}'.format(100*((obj_fcn[i - 1] -
+                                                          obj_fcn[i]) /
+                                                         obj_fcn[i - 1])),
+                                    True)
 
     # if objective function has increased
                 if obj_fcn[i] > obj_fcn[i - 1]:
@@ -798,7 +806,7 @@ def fuzzy_dist(cent, data, uuu, expo, cltype, cov_constr):
             dtmp.append(np.sum(np.dot(dcent, mmm) * dcent, 1).T)
         ddd = np.sqrt(np.array(dtmp))
 # GK
-    elif cltype == 'GK' or cltype == 'gk':
+    elif cltype in ['GK', 'gk']:
         m_f = uuu ** expo
         dtmp = []
         for j in range(no_cent):
@@ -822,10 +830,10 @@ def fuzzy_dist(cent, data, uuu, expo, cltype, cov_constr):
         # GK Code
             mmm = np.linalg.det(aaa)**(1.0/no_datasets)*np.linalg.pinv(aaa)
             dtmp.append(np.sum(np.dot(dcent, mmm) * dcent, 1).T)
-#            d[j,:] = np.sum((dcent*M*dcent),2).T
+            # d[j,:] = np.sum((dcent*M*dcent),2).T
         ddd = np.sqrt(np.array(dtmp))
 # GG
-    elif cltype == 'GG' or cltype == 'gg':
+    elif cltype in ['GG', 'gg']:
         m_f = uuu ** expo
         dtmp = []
         for j in range(no_cent):
@@ -852,17 +860,16 @@ def fuzzy_dist(cent, data, uuu, expo, cltype, cov_constr):
             t_1 = np.linalg.det(aaa)**0.5/ppp
             t_4 = np.linalg.pinv(aaa)
             t_5 = np.dot(dcent, t_4) * dcent * 0.5
-#                t_6[t_6 > maxnumexp] = maxnumexp
+            # t_6[t_6 > maxnumexp] = maxnumexp
             t_7 = np.exp(t_5)
             t_9 = t_1 * t_7
             t_10 = np.sum(t_9, 1).T
             dtmp.append(t_10)
-#                dtmp.append(np.sum((np.linalg.det(aaa)) ** 0.5 / ppp *
-#                            np.exp(np.dot(dcent, np.linalg.pinv(aaa)) *
-#                                   dcent * 0.5), 1).T)
+            # dtmp.append(np.sum((np.linalg.det(aaa)) ** 0.5 / ppp *
+            #             np.exp(np.dot(dcent, np.linalg.pinv(aaa)) *
+            #                   dcent * 0.5), 1).T)
         ddd = np.sqrt(np.array(dtmp))
-    ddd[ddd == 0] = 1e-10  # avoid, that a data point equals a cluster
-#                                center
+    ddd[ddd == 0] = 1e-10  # avoid, that a data point equals a cluster center
     if (ddd == np.inf).max() == True:
         ddd[ddd == np.inf] = np.random.normal() * 1e-10  # solve break
 
