@@ -35,10 +35,10 @@ from matplotlib.patches import Polygon
 from matplotlib.lines import Line2D
 from matplotlib.path import Path
 from matplotlib.ticker import NullFormatter
-from matplotlib.backends.backend_qt5agg import FigureCanvas
+from matplotlib.backends.backend_qt5agg import FigureCanvasQTAgg
 
 
-class GraphHist(FigureCanvas):
+class GraphHist(FigureCanvasQTAgg):
     """Graph Hist."""
 
     def __init__(self, parent=None):
@@ -155,7 +155,8 @@ class GraphHist(FigureCanvas):
         self.axscatter.get_yaxis().set_visible(False)
 
         self.csp = self.axscatter.imshow(xymahist.T, interpolation='nearest',
-                                         cmap=cm.jet, aspect='auto')
+                                         cmap=cm.get_cmap('jet'),
+                                         aspect='auto')
 
         self.csp.set_clim(xymahist.min(), xymahist.max())
         self.csp.changed()
@@ -254,7 +255,7 @@ class GraphHist(FigureCanvas):
         self.polyi.draw_callback()
 
 
-class GraphMap(FigureCanvas):
+class GraphMap(FigureCanvasQTAgg):
     """
     Graph Map.
 
@@ -295,7 +296,7 @@ class GraphMap(FigureCanvas):
         self.subplot.get_xaxis().set_visible(False)
         self.subplot.get_yaxis().set_visible(False)
 
-        self.csp = self.subplot.imshow(dat.data, cmap=cm.jet)
+        self.csp = self.subplot.imshow(dat.data, cmap=cm.get_cmap('jet'))
         self.subplot.figure.colorbar(self.csp)
 
         self.figure.canvas.draw()
@@ -487,6 +488,10 @@ class PolygonInteractor(QtCore.QObject):
             return
         if event.button != 1:
             return
+
+        if self.ax.get_navigate_mode() is not None:
+            return
+
         self._ind = self.get_ind_under_point(event)
 
         if self._ind is None:
@@ -521,9 +526,16 @@ class PolygonInteractor(QtCore.QObject):
                     imin = i
             i = imin
 
-            self.poly.xy = np.array(list(self.poly.xy[:i + 1]) +
-                                    [(event.xdata, event.ydata)] +
-                                    list(self.poly.xy[i + 1:]))
+            if np.array_equal(self.poly.xy, np.ones((2, 2))):
+                self.poly.set_xy([[event.xdata, event.ydata]])
+            else:
+                self.poly.xy = np.array(list(self.poly.xy[:i + 1]) +
+                                        [(event.xdata, event.ydata)] +
+                                        list(self.poly.xy[i + 1:]))
+
+            # self.poly.xy = np.array(list(self.poly.xy[:i + 1]) +
+            #                         [(event.xdata, event.ydata)] +
+            #                         list(self.poly.xy[i + 1:]))
             self.line.set_data(list(zip(*self.poly.xy)))
 
             self.canvas.restore_region(self.background)
@@ -619,6 +631,10 @@ class ScatterPlot(QtWidgets.QDialog):
         self.c = [0, 1, 0]
         self.m = [0, 0]
         self.dat_tmp = None
+        if parent is None:
+            self.showprocesslog = print
+        else:
+            self.showprocesslog = parent.showprocesslog
 
         self.map = GraphMap(self)
         self.hist = GraphHist(self)
@@ -793,8 +809,9 @@ class ScatterPlot(QtWidgets.QDialog):
 
         """
         if 'Raster' not in self.indata:
-            print('Error: You must have a multi-band raster dataset in '
-                  'addition to your cluster analysis results')
+            self.showprocesslog('Error: You must have a multi-band raster '
+                                'dataset in addition to your cluster analysis'
+                                ' results')
             return False
 
         self.dat_tmp = self.indata['Raster']
@@ -883,7 +900,6 @@ class ScatterPlot(QtWidgets.QDialog):
 
         return projdata
 
-
     def update_map(self, polymask):
         """
         Update map.
