@@ -52,6 +52,10 @@ class ImageSeg(QtWidgets.QDialog):
 
     def __init__(self, parent=None):
         super().__init__(parent)
+        if parent is None:
+            self.showprocesslog = print
+        else:
+            self.showprocesslog = parent.showprocesslog
 
         self.parent = parent
         self.indata = {}
@@ -224,7 +228,7 @@ class ImageSeg(QtWidgets.QDialog):
         """
         rows, cols, bands = data.shape
 
-        print('Initialising...')
+        self.showprocesslog('Initialising...')
 
         olist = {}
         slist = {}
@@ -247,12 +251,12 @@ class ImageSeg(QtWidgets.QDialog):
                     nlist[(k, i*cols+j)] = 1
                 omap[i, j] = i*cols+j
 
-        print('merging...')
+        self.showprocesslog('merging...')
 
         omap = self.segment2(omap, olist, slist, mlist, nlist, bands,
                              doshape, wcompact, wcolor, scale)
 
-        print('renumbering...')
+        self.showprocesslog('renumbering...')
         tmp = np.unique(omap)
 
         for i, val in enumerate(tmp):
@@ -295,7 +299,6 @@ class ImageSeg(QtWidgets.QDialog):
             DESCRIPTION.
 
         """
-        """Segment 2."""
         wband = np.ones(bands)/bands
 
         cnt = 0
@@ -317,7 +320,7 @@ class ImageSeg(QtWidgets.QDialog):
             self.pbar.setMaximum(clen)
             self.pbar.setMinimum(0)
             self.pbar.setValue(0)
-            print('Iteration number: '+str(cnt))
+            self.showprocesslog('Iteration number: '+str(cnt))
             oldperc = 0
 
             olist3 = olist.copy()
@@ -496,7 +499,6 @@ def get_l(data):
     return ltmp
 
 
-
 def test():
     """Main testing routine."""
     data1 = skimage.data.coffee()  # 400x600 50.6 secs
@@ -506,12 +508,12 @@ def test():
     doshape = True
     scale = 1000
 
-    omap = segment1(data1, scale=scale, wcolor=wcolor,
-                    wcompact=wcompact, doshape=doshape)
+    # omap = segment1(data1, scale=scale, wcolor=wcolor,
+    #                 wcompact=wcompact, doshape=doshape)
 
-    plt.figure(figsize=(8, 8))
-    plt.imshow(omap)
-    plt.show()
+    # plt.figure(figsize=(8, 8))
+    # plt.imshow(omap)
+    # plt.show()
 
 #    xall = []
 #    yall = []
