@@ -35,8 +35,8 @@ from matplotlib import cm
 from matplotlib.artist import Artist
 from matplotlib.patches import Polygon as mPolygon
 from matplotlib.lines import Line2D
-from matplotlib.backends.backend_qt5agg import FigureCanvas
-from matplotlib.backends.backend_qt5agg import NavigationToolbar2QT
+from matplotlib.backends.backend_qt5agg import FigureCanvasQTAgg
+from matplotlib.backends.backend_qt5 import NavigationToolbar2QT
 import geopandas as gpd
 from shapely.geometry import Polygon
 from PIL import Image, ImageDraw
@@ -46,13 +46,11 @@ import sklearn.metrics as skm
 from sklearn.ensemble import RandomForestClassifier
 from sklearn.tree import DecisionTreeClassifier
 from sklearn.svm import SVC
-
-sys.path.append(os.path.abspath(os.path.join(os.path.dirname(__file__),
-                                             '..//..')))
 from pygmi.raster.datatypes import Data
+from pygmi.misc import frm
 
 
-class GraphMap(FigureCanvas):
+class GraphMap(FigureCanvasQTAgg):
     """
     Graph Map.
 
@@ -90,10 +88,18 @@ class GraphMap(FigureCanvas):
 
         self.figure.clf()
         self.subplot = self.figure.add_subplot(111)
-        self.subplot.get_xaxis().set_visible(False)
-        self.subplot.get_yaxis().set_visible(False)
+        # self.subplot.get_xaxis().set_visible(False)
+        # self.subplot.get_yaxis().set_visible(False)
 
-        self.csp = self.subplot.imshow(dat.data, cmap=cm.jet)
+        self.csp = self.subplot.imshow(dat.data, extent=dat.extent,
+                                       cmap=cm.get_cmap('jet'))
+        axes = self.figure.gca()
+
+        axes.set_xlabel('Eastings')
+        axes.set_ylabel('Northings')
+
+        axes.xaxis.set_major_formatter(frm)
+        axes.yaxis.set_major_formatter(frm)
 
         self.figure.canvas.draw()
 
@@ -294,6 +300,9 @@ class PolygonInteractor(QtCore.QObject):
         if self.isactive is False:
             return
 
+        if self.ax.get_navigate_mode() is not None:
+            return
+
         self._ind = self.get_ind_under_point(event)
 
         if self._ind is None:
@@ -327,9 +336,15 @@ class PolygonInteractor(QtCore.QObject):
                     imin = i
             i = imin
 
-            self.poly.xy = np.array(list(self.poly.xy[:i + 1]) +
-                                    [(event.xdata, event.ydata)] +
-                                    list(self.poly.xy[i + 1:]))
+            if np.array_equal(self.poly.xy, np.ones((2, 2))):
+                self.poly.set_xy([[event.xdata, event.ydata]])
+            else:
+                self.poly.xy = np.array(list(self.poly.xy[:i + 1]) +
+                                        [(event.xdata, event.ydata)] +
+                                        list(self.poly.xy[i + 1:]))
+            # self.poly.xy = np.array(list(self.poly.xy[:i + 1]) +
+            #                         [(event.xdata, event.ydata)] +
+            #                         list(self.poly.xy[i + 1:]))
             self.line.set_data(list(zip(*self.poly.xy)))
 
             self.canvas.restore_region(self.background)
@@ -421,6 +436,11 @@ class SuperClass(QtWidgets.QDialog):
 
     def __init__(self, parent=None):
         super().__init__(parent)
+        if parent is None:
+            self.showprocesslog = print
+        else:
+            self.showprocesslog = parent.showprocesslog
+
         self.indata = {}
         self.outdata = {}
         self.parent = parent
@@ -666,7 +686,7 @@ class SuperClass(QtWidgets.QDialog):
         None.
 
         """
-        print(row, column)
+        self.showprocesslog(row, column)
 
     def on_apoly(self):
         """
@@ -763,6 +783,8 @@ class SuperClass(QtWidgets.QDialog):
         coords = list(self.df.loc[0, 'geometry'].exterior.coords)
         self.map.polyi.new_poly(coords)
 
+        return True
+
     def save_shape(self):
         """
         Save shapefile.
@@ -793,8 +815,9 @@ class SuperClass(QtWidgets.QDialog):
 
         """
         if 'Raster' not in self.indata:
-            print('Error: You must have a multi-band raster dataset in '
-                  'addition to your cluster analysis results')
+            self.showprocesslog('Error: You must have a multi-band raster '
+                                'dataset in addition to your cluster '
+                                'analysis results')
             return False
 
         self.map.data = self.indata['Raster']
@@ -845,8 +868,8 @@ class SuperClass(QtWidgets.QDialog):
         dat_out[-1].metadata['Cluster']['no_clusters'] = i
         dat_out[-1].metadata['Cluster']['center'] = np.zeros([i, len(data)])
         dat_out[-1].metadata['Cluster']['center_std'] = np.zeros([i, len(data)])
-#        if cfit.labels_.max() > 0:
-#            dat_out[-1].metadata['Cluster']['vrc'] = skm.calinski_harabasz_score(X, cfit.labels_)
+        # if cfit.labels_.max() > 0:
+        #     dat_out[-1].metadata['Cluster']['vrc'] = skm.calinski_harabasz_score(X, cfit.labels_)
 
         m = []
         s = []
@@ -857,8 +880,8 @@ class SuperClass(QtWidgets.QDialog):
         dat_out[-1].metadata['Cluster']['center'] = np.array(m)
         dat_out[-1].metadata['Cluster']['center_std'] = np.array(s)
 
-#        self.log = ('Cluster complete' + ' (' + self.cltype+')')
-#
+        # self.log = ('Cluster complete' + ' (' + self.cltype+')')
+
         dat_out[-1].xdim = data[0].xdim
         dat_out[-1].ydim = data[0].ydim
         dat_out[-1].dataid = 'Clusters: '+str(dat_out[-1].metadata['Cluster']['no_clusters'])
@@ -871,7 +894,7 @@ class SuperClass(QtWidgets.QDialog):
             i.nullvalue = 0
             i.data.data[i.data.mask] = 0
 
-        print('Cluster complete')
+        self.showprocesslog('Cluster complete')
 
         self.outdata['Cluster'] = dat_out
         self.outdata['Raster'] = self.indata['Raster']
@@ -959,15 +982,26 @@ class SuperClass(QtWidgets.QDialog):
         rows, cols = self.map.data[0].data.shape
         masks = {}
         for _, row in self.df.iterrows():
-            pixels = list(row['geometry'].exterior.coords)
+            # pixels = list(row['geometry'].exterior.coords)
+
+            pixels = np.array(row['geometry'].exterior.coords)
+            pixels[:, 0] = pixels[:, 0]-self.map.data[0].extent[0]
+            pixels[:, 0] /= self.map.data[0].xdim
+            pixels[:, 1] = self.map.data[0].extent[3]-pixels[:, 1]
+            pixels[:, 1] /= self.map.data[0].ydim
+
+            pixels = tuple(map(tuple, pixels))
+
             cname = row['class']
             if cname not in masks:
                 masks[cname] = np.zeros((rows, cols), dtype=bool)
 
             rasterPoly = Image.new("L", (cols, rows), 1)
             rasterize = ImageDraw.Draw(rasterPoly)
-            rasterize.polygon(pixels)
+            rasterize.polygon(pixels, 0)
             mask = np.array(rasterPoly, dtype=bool)
+            # plt.imshow(mask)
+            # plt.show()
 
             masks[cname] = np.logical_or(~mask, masks[cname])
 
@@ -988,15 +1022,14 @@ class SuperClass(QtWidgets.QDialog):
         lbls = np.unique(y)
 
         if len(lbls) < 2:
-            print('Error: You need at least two classes')
-            return False
+            self.showprocesslog('Error: You need at least two classes')
+            # return False
 
         # Encoding categorical data
-#        labelencoder = LabelEncoder()
-#        y = labelencoder.fit_transform(y)
+        # labelencoder = LabelEncoder()
+        # y = labelencoder.fit_transform(y)
         X_train, X_test, y_train, y_test = train_test_split(x, y, stratify=y)
 
-
         classifier.fit(X_train, y_train)
 
         return classifier, lbls, datall, X_test, y_test
