@@ -50,6 +50,10 @@ class ProcessData(QtWidgets.QDialog):
 
     def __init__(self, parent=None):
         super().__init__(parent)
+        if parent is None:
+            self.showprocesslog = print
+        else:
+            self.showprocesslog = parent.showprocesslog
 
         self.indata = {}
         self.outdata = {}
@@ -126,10 +130,10 @@ class ProcessData(QtWidgets.QDialog):
         """
         tmp = []
         if 'Line' not in self.indata:
-            print('No Line Data')
+            self.showprocesslog('No Line Data')
             return False
         if 'Gravity' not in self.indata['Line']:
-            print('Not Gravity Data')
+            self.showprocesslog('Not Gravity Data')
             return False
 
         if not nodialog:
@@ -143,14 +147,14 @@ class ProcessData(QtWidgets.QDialog):
             float(self.basethres.text())
             float(self.knownbase.text())
         except ValueError:
-            print('Value Error')
+            self.showprocesslog('Value Error')
             return False
 
         if self.knownstat.text() != 'None':
             try:
                 float(self.knownstat.text())
             except ValueError:
-                print('Value Error')
+                self.showprocesslog('Value Error')
                 return False
 
         if tmp != 1:
@@ -254,8 +258,8 @@ class ProcessData(QtWidgets.QDialog):
 
         dcor = np.interp(x, xp, fp)
 
-        print('Quality Control')
-        print('---------------')
+        self.showprocesslog('Quality Control')
+        self.showprocesslog('---------------')
         tmp = driftdat['DECTIMEDATE'].values.astype(int)
         tmp2 = []
         ix = []
@@ -275,8 +279,8 @@ class ProcessData(QtWidgets.QDialog):
             dcor2 = fp[filt]
             drifttime = (x2[-1]-x2[0])
             driftrate = (dcor2[-1]-dcor2[0])/drifttime
-            print(f'Day {iday+1} drift: {driftrate:.3e} mGal/min over '
-                  f'{drifttime:.3f} minutes.')
+            self.showprocesslog(f'Day {iday+1} drift: {driftrate:.3e} '
+                                f'mGal/min over {drifttime:.3f} minutes.')
 
         xp2 = xp1/86400 + ix+1
 
@@ -289,10 +293,7 @@ class ProcessData(QtWidgets.QDialog):
             plt.xticks(range(1, ix[-1]+2, 1))
             plt.tight_layout()
 
-            try:
-                plt.get_current_fig_manager().window.setWindowIcon(self.parent.windowIcon())
-            except:
-                pass
+            plt.get_current_fig_manager().window.setWindowIcon(self.parent.windowIcon())
             plt.show()
 
         gobs = pdat['GRAV'] - dcor + float(self.absbase.text())
@@ -536,11 +537,11 @@ def test():
     """Test routine."""
     APP = QtWidgets.QApplication(sys.argv)  # Necessary to test Qt Classes
 
-    grvfile = r'C:\WorkData\Gravity\skeifontein 2018.txt'
-    gpsfile = r'C:\WorkData\Gravity\skei_dgps.csv'
+    grvfile = r'C:\Work\Workdata\gravity\skeifontein 2018.txt'
+    gpsfile = r'C:\Work\Workdata\gravity\skei_dgps.csv'
 
-    grvfile = r'C:\WorkData\Gravity\Laxeygarvity until2511.txt'
-    gpsfile = r'C:\WorkData\Gravity\laxey.dgps.csv'
+    grvfile = r'C:\Work\Workdata\gravity\Laxeygarvity until2511.txt'
+    gpsfile = r'C:\Work\Workdata\gravity\laxey.dgps.csv'
 
 # Import Data
     IO = iodefs.ImportCG5(None)
@@ -555,7 +556,7 @@ def test():
     PD.knownbase.setText('978864.74')
     PD.calcbase()
 
-    PD.settings(True)
+    PD.settings(False)
 
     datout = PD.outdata['Line']
 
@@ -571,4 +572,4 @@ def test():
 if __name__ == "__main__":
     test()
 
-    print('Finished!')
\ No newline at end of file
+    print('Finished!')
