@@ -28,7 +28,6 @@ import os
 from PyQt5 import QtWidgets, QtCore
 import numpy as np
 import pandas as pd
-from pygmi.vector.datatypes import LData
 import pygmi.menu_default as menu_default
 
 
@@ -54,6 +53,10 @@ class ImportCG5(QtWidgets.QDialog):
 
     def __init__(self, parent):
         super().__init__(parent)
+        if parent is None:
+            self.showprocesslog = print
+        else:
+            self.showprocesslog = parent.showprocesslog
 
         self.pbar = None  # self.parent.pbar
         self.parent = parent
@@ -161,7 +164,8 @@ class ImportCG5(QtWidgets.QDialog):
                 return False
 
         if self.line.currentText() == self.station.currentText():
-            print('Your line column cannot be the same as your station column')
+            self.showprocesslog('Your line column cannot be the same as your '
+                                'station column')
             return False
 
         tmp = [self.line.currentText(),
@@ -171,9 +175,10 @@ class ImportCG5(QtWidgets.QDialog):
                self.zchan.currentText()]
 
         if len(set(tmp)) != len(tmp):
-            print('Unable to import, two of your GPS file columns are the '
-                  'same. Make sure you have a line column in your GPS file, '
-                  'and that you did not specify the same column twice.')
+            self.showprocesslog('Unable to import, two of your GPS file '
+                                'columns are the same. Make sure you have a '
+                                'line column in your GPS file, and that you '
+                                'did not specify the same column twice.')
             return False
 
         # Rename columns
@@ -186,6 +191,30 @@ class ImportCG5(QtWidgets.QDialog):
 
         self.df_gps.rename(columns=cren, inplace=True)
 
+        if self.df_gps.latitude.dtype == 'O':
+            filt = self.df_gps.latitude.str.contains('S')
+            self.df_gps.latitude.loc[filt] = '-'+self.df_gps.latitude[filt]
+            self.df_gps.latitude.replace('S', '', inplace=True, regex=True)
+            self.df_gps.latitude.replace('N', '', inplace=True, regex=True)
+            try:
+                self.df_gps.latitude = pd.to_numeric(self.df_gps.latitude)
+            except ValueError:
+                self.showprocesslog('You have characters in your latitude'
+                                    ' string which could not be converted.')
+                return False
+
+        if self.df_gps.longitude.dtype == 'O':
+            filt = self.df_gps.longitude.str.contains('W')
+            self.df_gps.longitude.loc[filt] = '-'+self.df_gps.longitude[filt]
+            self.df_gps.longitude.replace('W', '', inplace=True, regex=True)
+            self.df_gps.longitude.replace('E', '', inplace=True, regex=True)
+            try:
+                self.df_gps.longitude = pd.to_numeric(self.df_gps.longitude)
+            except ValueError:
+                self.showprocesslog('You have characters in your longitude'
+                                    ' string which could not be converted.')
+                return False
+
         # Get rid of text in line columns
         if self.df_gps['line'].dtype == object:
             self.df_gps['line'] = self.df_gps['line'].str.replace(r'\D', '')
@@ -234,8 +263,8 @@ class ImportCG5(QtWidgets.QDialog):
         dlist = dlist[dlist.STATION < 10000]
 
         if dlist.size > 0:
-            print('Warning, the following are duplicated:' )
-            print(dlist.to_string(index=False))
+            self.showprocesslog('Warning, the following are duplicated:')
+            self.showprocesslog(dlist.to_string(index=False))
 
         return True
 
