@@ -36,7 +36,6 @@ pygmi packages.
 """
 
 import json
-import pdb
 import sys
 import os
 import pkgutil
@@ -45,6 +44,7 @@ import importlib
 from PyQt5 import QtWidgets, QtCore, QtGui
 import numpy as np
 from matplotlib import rcParams
+from matplotlib import interactive
 import pygmi
 import pygmi.menu_default as menu_default
 import pygmi.misc as misc
@@ -53,6 +53,7 @@ import pygmi.misc as misc
 # rcParams['font.size'] = 6.0
 rcParams['axes.formatter.limits'] = [-12, 12]
 rcParams['axes.formatter.useoffset'] = False
+interactive(False)
 
 QtCore.QLocale.setDefault(QtCore.QLocale.c())
 
@@ -195,8 +196,8 @@ class DiagramItem(QtWidgets.QGraphicsPolygonItem):
         Class name being referenced
     """
 
-    def __init__(self, diagram_type, context_menu, my_class, parent=None):
-        super().__init__(parent)
+    def __init__(self, diagram_type, context_menu, my_class, parent):
+        super().__init__()
 
         self.arrows = []
         self.parent = my_class.parent
@@ -207,6 +208,7 @@ class DiagramItem(QtWidgets.QGraphicsPolygonItem):
         self.is_import = False
         self.text_item = None
         self.my_class_name = ''
+        self.showprocesslog = parent.showprocesslog
 
         if hasattr(self.my_class, 'arrows'):
             self.my_class.arrows = self.arrows
@@ -322,9 +324,6 @@ class DiagramItem(QtWidgets.QGraphicsPolygonItem):
         """
         self.setBrush(QtGui.QColor(255, 0, 0, 127))
 
-        sys.stdout = self.parent.stdoutnew
-        sys.breakpointhook = self.parent.pdb
-
         temp = self.settings()
         self.parent.scene.selected_item_info()
 
@@ -378,13 +377,13 @@ class DiagramItem(QtWidgets.QGraphicsPolygonItem):
             return False
 
         self.my_class.parent.process_is_active()
-        print(self.my_class_name+' busy...')
+        self.showprocesslog(self.my_class_name+' busy...')
         iflag = self.my_class.settings(nodialog)
         self.my_class.parent.process_is_active(False)
         if iflag:
-            print(self.my_class_name+' finished!')
+            self.showprocesslog(self.my_class_name+' finished!')
         else:
-            print(self.my_class_name+' cancelled.')
+            self.showprocesslog(self.my_class_name+' cancelled.')
         return iflag
 
 
@@ -559,12 +558,7 @@ class MainWidget(QtWidgets.QMainWindow):
         self.context_menu = {}
         self.add_to_context('Basic')
 
-        self.stdoutold = sys.stdout
-        self.stdoutnew = EmittingStream(textWritten=self.read_output)
-
-        sys.stdout = self.stdoutnew
-        sys.breakpointhook = self.pdb
-        # sys.stderr = EmittingStream(textWritten=self.read_output)
+        self.stdio_redirect = EmittingStream(self.showprocesslog)
 
         self.menubar = QtWidgets.QMenuBar()
 
@@ -610,12 +604,26 @@ class MainWidget(QtWidgets.QMainWindow):
                 onerror=lambda x: None):
             menus.append(modname)
 
-        menus.pop(menus.index('pygmi.em.menu'))
+        # menus.pop(menus.index('pygmi.em.menu'))
         raster_menu = menus.pop(menus.index('pygmi.raster.menu'))
         vector_menu = menus.pop(menus.index('pygmi.vector.menu'))
         menus = [raster_menu, vector_menu]+menus
-
         menus = [i for i in menus if 'menu' in i[-5:]]
+
+        # menus = ['pygmi.raster.menu',
+        #          'pygmi.em.menu',
+        #          'pygmi.vector.menu',
+        #          'pygmi.bholes.menu',
+        #          'pygmi.clust.menu',
+        #          'pygmi.eseis.menu',
+        #          'pygmi.grav.menu',
+        #          'pygmi.mag.menu',
+        #          'pygmi.mt.menu',
+        #          'pygmi.pfmod.menu',
+        #          'pygmi.rsense.menu',
+        #          'pygmi.seis.menu',
+        #          ]
+
         start = Startup(len(menus)+1)
         start.update()
 
@@ -647,40 +655,6 @@ class MainWidget(QtWidgets.QMainWindow):
         self.action_send_to_back.triggered.connect(self.send_to_back)
         self.action_help.triggered.connect(self.help_docs)
 
-    def __del__(self):
-        """
-        Restore sys.stdout
-
-        Returns
-        -------
-        None.
-
-        """
-        sys.stdout = self.stdoutold
-
-    def pdb(self):
-        """
-        Routine to make sure stdout is restored when using debugger.
-
-        Returns
-        -------
-        None.
-
-        """
-        sys.stdout = self.stdoutold
-
-        debugger = pdb.Pdb()
-        debugger.reset()
-
-        # your custom stuff here
-        # debugger.do_where(None) # run the "where" command
-
-        # invoke the interactive debugging prompt
-        users_frame = sys._getframe().f_back  # frame where user invoked pdb()
-        debugger.interaction(users_frame, None)
-
-        sys.stdout = self.stdoutnew
-
 # Start of Functions
     def setupui(self):
         """
@@ -871,7 +845,8 @@ class MainWidget(QtWidgets.QMainWindow):
         item : DiagramItem
             Return a DiagramItem object
         """
-        item = DiagramItem(item_type, self.scene.my_item_menu, class_name)
+        item = DiagramItem(item_type, self.scene.my_item_menu, class_name,
+                           self)
         item_color = self.scene.my_item_color
 
         item_name = item_name.replace(' ', '\n')
@@ -946,9 +921,6 @@ class MainWidget(QtWidgets.QMainWindow):
         newitem : custom class
             newitem is the class to be called by the context menu item
         """
-        sys.stdout = self.stdoutnew
-        sys.breakpointhook = self.pdb
-
         outdata = self.get_outdata()
 
         for odata in outdata:
@@ -967,9 +939,6 @@ class MainWidget(QtWidgets.QMainWindow):
         newitem : custom class
             newitem is the class to be called by the context menu item
         """
-        sys.stdout = self.stdoutnew
-        sys.breakpointhook = self.pdb
-
         indata = self.get_indata()
 
         for idata in indata:
@@ -1004,18 +973,6 @@ class MainWidget(QtWidgets.QMainWindow):
             self.textbrowser_processlog.setStyleSheet(
                 '* { background-color: rgb(255, 255, 255); }')
 
-    def read_output(self, text):
-        """
-        Reads std out and sends it to process log.
-
-        Returns
-        -------
-        None.
-
-        """
-
-        self.showprocesslog(text)
-
     def load(self):
         """
         Loads project state from JSON file.
@@ -1027,7 +984,7 @@ class MainWidget(QtWidgets.QMainWindow):
         """
 
         self.process_is_active()
-        print('Project load busy...')
+        self.showprocesslog('Project load busy...')
 
         ifile, _ = QtWidgets.QFileDialog.getOpenFileName(
             self, 'Open Project', '.', 'PyGMI project (*.json);;')
@@ -1083,6 +1040,7 @@ class MainWidget(QtWidgets.QMainWindow):
             end_item.update_indata()
 
         self.process_is_active(False)
+        return True
 
     def save(self):
         """
@@ -1119,6 +1077,7 @@ class MainWidget(QtWidgets.QMainWindow):
 
         with open(ofile, 'w') as todisk:
             json.dump(ilist, todisk, indent=4)
+        return True
 
     def run(self):
         """
@@ -1137,7 +1096,7 @@ class MainWidget(QtWidgets.QMainWindow):
                 alist[str(item)] = item
 
         if not alist:
-            print('No connections. Aborting run.')
+            self.showprocesslog('No connections. Aborting run.')
             return
 
         # Collect only items recieving data
@@ -1243,7 +1202,7 @@ class MainWidget(QtWidgets.QMainWindow):
 
         txtobj = self.textbrowser_processlog
 
-        txtmsg = str(txtobj.toPlainText())
+        txtmsg = str(txtobj.toPlainText()+'\n')
         if replacelast is True:
             txtmsg = txtmsg[:txtmsg.rfind('\n')]
             txtmsg = txtmsg[:txtmsg.rfind('\n')]
@@ -1314,12 +1273,9 @@ class Startup(QtWidgets.QDialog):
 
 class EmittingStream(QtCore.QObject):
     """ Class to intercept stdout for later use in a textbox """
-    textWritten = QtCore.pyqtSignal(str)
-    # terminal = sys.stdout
 
-    # def __init__(self, textWritten):
-    #     self.terminal = sys.stdout
-    #     self.textWritten = textWritten
+    def __init__(self, textWritten):
+        self.textWritten = textWritten
 
     def write(self, text):
         """
@@ -1335,8 +1291,7 @@ class EmittingStream(QtCore.QObject):
         None.
 
         """
-        # self.terminal.write(text)
-        self.textWritten.emit(str(text))
+        self.textWritten(str(text))
 
     def flush(self):
         """
@@ -1365,7 +1320,11 @@ class EmittingStream(QtCore.QObject):
 def main():
     """Entry point for the PyGMI software"""
     app = QtWidgets.QApplication(sys.argv)
-    app.setAttribute(QtCore.Qt.AA_DisableWindowContextHelpButton)
+    # The try statement is because this command is only available for qt>=5.10
+    try:
+        app.setAttribute(QtCore.Qt.AA_DisableWindowContextHelpButton)
+    except AttributeError:
+        pass
 
     screen_resolution = app.desktop().screenGeometry()
     width, height = screen_resolution.width(), screen_resolution.height()
