@@ -90,6 +90,10 @@ class BIRRP(QtWidgets.QDialog):
 
     def __init__(self, parent=None):
         super().__init__(parent)
+        if parent is None:
+            self.showprocesslog = print
+        else:
+            self.showprocesslog = parent.showprocesslog
 
         self.pbar = None  # self.parent.pbar
         self.parent = parent
@@ -146,8 +150,11 @@ class BIRRP(QtWidgets.QDialog):
             self.wstim[i] = QtWidgets.QLineEdit('YYYY-MM-DD HH:MM:SS')
             self.wetim[i] = QtWidgets.QLineEdit('YYYY-MM-DD HH:MM:SS')
 
-            self.pb_arfilnam[i] = QtWidgets.QPushButton('ARFILNAM: '+i+' AR filter filename')
-            self.pb_cpar[i] = QtWidgets.QPushButton('CPAR: '+i+' filter parameters filename')
+            self.pb_arfilnam[i] = QtWidgets.QPushButton('ARFILNAM: ' + i +
+                                                        ' AR filter filename')
+            self.pb_cpar[i] = QtWidgets.QPushButton('CPAR: ' + i +
+                                                    ' filter parameters '
+                                                    'filename')
             self.pb_filnam[i] = QtWidgets.QPushButton('FILNAM: '+i+' filename')
 
         self.thetae = QtWidgets.QLineEdit('0,90,0')
@@ -167,8 +174,8 @@ class BIRRP(QtWidgets.QDialog):
         """
         buttonbox = QtWidgets.QDialogButtonBox()
         # helpdocs = menu_default.HelpButton('pygmi.grav.iodefs.importpointdata')
-        pb_importbirrp = QtWidgets.QPushButton('Import BIRRP '
-                                               'configuration file')
+        pb_importbirrp = QtWidgets.QPushButton('Import BIRRP configuration '
+                                               'file')
         pb_runbirrp = QtWidgets.QPushButton('Save BIRRP configuration file')  #' and run BIRRP')
 
         self.ilev.setDisabled(True)
@@ -303,7 +310,7 @@ class BIRRP(QtWidgets.QDialog):
 
         ilev = data.pop(0)
         if int(ilev) != 0:
-            print('not supported')
+            self.showprocesslog('not supported')
             return
         nout = int(data.pop(0))
         ninp = int(data.pop(0))
@@ -319,7 +326,7 @@ class BIRRP(QtWidgets.QDialog):
         if nout == 3:
             nz = int(data.pop(0))
         elif nout == 1:
-            print('not supported')
+            self.showprocesslog('not supported')
             return
         c2threshe1 = ''
         if int(nout) == 3 and int(nz) == 0:
@@ -331,13 +338,13 @@ class BIRRP(QtWidgets.QDialog):
         imode = int(data.pop(0))
         jmode = int(data.pop(0))
         if imode != 0:
-            print('not supported')
+            self.showprocesslog('not supported')
             return
         nread = ''
         if jmode == 0:
             nread = data.pop(0)
         else:
-            print('not supported')
+            self.showprocesslog('not supported')
             return
 
         nfil = {}
