@@ -31,9 +31,9 @@ import glob
 import platform
 from PyQt5 import QtWidgets, QtCore
 import numpy as np
-from matplotlib.backends.backend_qt5agg import FigureCanvas
+from matplotlib.backends.backend_qt5agg import FigureCanvasQTAgg
 from matplotlib.figure import Figure
-from matplotlib.backends.backend_qt5agg import NavigationToolbar2QT
+from matplotlib.backends.backend_qt5 import NavigationToolbar2QT
 from matplotlib.patches import Rectangle
 import mtpy.modeling.occam1d as occam1d
 from mtpy.core.mt import MT
@@ -66,6 +66,10 @@ class Metadata(QtWidgets.QDialog):
 
     def __init__(self, parent=None):
         super().__init__(parent)
+        if parent is None:
+            self.showprocesslog = print
+        else:
+            self.showprocesslog = parent.showprocesslog
 
         self.indata = {}
         self.outdata = {}
@@ -204,7 +208,7 @@ class Metadata(QtWidgets.QDialog):
 #            odata.utm_zone = float(self.dsb_utmzone.text())
             odata.rotation_angle = float(self.dsb_rot.text())
         except ValueError:
-            print('Value error - abandoning changes')
+            self.showprocesslog('Value error - abandoning changes')
 
         indx = self.combobox_bandid.currentIndex()
         txt = self.combobox_bandid.itemText(indx)
@@ -276,11 +280,9 @@ class Metadata(QtWidgets.QDialog):
         return True
 
 
-class MyMplCanvas(FigureCanvas):
+class MyMplCanvas(FigureCanvasQTAgg):
     """
     MPL Canvas class.
-
-    This routine will also allow the picking and movement of nodes of data.
     """
 
     def __init__(self, parent=None):
@@ -379,6 +381,11 @@ class StaticShiftEDI(QtWidgets.QDialog):
 
     def __init__(self, parent=None):
         super().__init__(parent)
+        if parent is None:
+            self.showprocesslog = print
+        else:
+            self.showprocesslog = parent.showprocesslog
+
         self.indata = {}
         self.outdata = {}
         self.data = None
@@ -529,7 +536,7 @@ class StaticShiftEDI(QtWidgets.QDialog):
         if 'MT - EDI' in self.indata:
             self.data = copy.deepcopy(self.indata['MT - EDI'])
         else:
-            print('No EDI data')
+            self.showprocesslog('No EDI data')
             return False
 
         self.combobox1.currentIndexChanged.disconnect()
@@ -599,6 +606,11 @@ class RotateEDI(QtWidgets.QDialog):
 
     def __init__(self, parent=None):
         super().__init__(parent)
+        if parent is None:
+            self.showprocesslog = print
+        else:
+            self.showprocesslog = parent.showprocesslog
+
         self.indata = {}
         self.outdata = {}
         self.data = None
@@ -741,7 +753,7 @@ class RotateEDI(QtWidgets.QDialog):
         if 'MT - EDI' in self.indata:
             self.data = copy.deepcopy(self.indata['MT - EDI'])
         else:
-            print('No EDI data')
+            self.showprocesslog('No EDI data')
             return False
 
         self.combobox1.currentIndexChanged.disconnect()
@@ -807,7 +819,7 @@ class RotateEDI(QtWidgets.QDialog):
         return projdata
 
 
-class MyMplCanvasPick(FigureCanvas):
+class MyMplCanvasPick(FigureCanvasQTAgg):
     """
     MPL Canvas class.
 
@@ -907,9 +919,11 @@ class MyMplCanvasPick(FigureCanvas):
             self.line2.set_data(xxx, yyy)
         elif event.button == 1:
             xxx, yyy = self.line.get_data()
-            rect = Rectangle((xxx[0], yyy[0]), event.xdata-xxx[0], yyy[1]-yyy[0])
+            rect = Rectangle((xxx[0], yyy[0]), event.xdata-xxx[0],
+                             yyy[1]-yyy[0])
             xxx, yyy = self.line2.get_data()
-            rect2 = Rectangle((xxx[0], yyy[0]), event.xdata-xxx[0], yyy[1]-yyy[0])
+            rect2 = Rectangle((xxx[0], yyy[0]), event.xdata-xxx[0],
+                              yyy[1]-yyy[0])
             self.maskrange = np.sort([xxx[0], event.xdata])
 
         self.figure.canvas.restore_region(self.background)
@@ -1081,6 +1095,11 @@ class EditEDI(QtWidgets.QDialog):
 
     def __init__(self, parent=None):
         super().__init__(parent)
+        if parent is None:
+            self.showprocesslog = print
+        else:
+            self.showprocesslog = parent.showprocesslog
+
         self.indata = {}
         self.outdata = {}
         self.data = None
@@ -1223,7 +1242,7 @@ class EditEDI(QtWidgets.QDialog):
         if 'MT - EDI' in self.indata:
             self.data = copy.deepcopy(self.indata['MT - EDI'])
         else:
-            print('No EDI data')
+            self.showprocesslog('No EDI data')
             return False
 
         self.combobox1.currentIndexChanged.disconnect()
@@ -1281,6 +1300,7 @@ class EditEDI(QtWidgets.QDialog):
 
         return projdata
 
+
 class MySlider(QtWidgets.QSlider):
     """
     My Slider
@@ -1288,6 +1308,7 @@ class MySlider(QtWidgets.QSlider):
     Custom class which allows clicking on a horizontal slider bar with slider
     moving to click in a single step.
     """
+
     def __init__(self, parent=None):
         super().__init__(parent)
 
@@ -1330,7 +1351,7 @@ class MySlider(QtWidgets.QSlider):
                                                                self.width()))
 
 
-class MyMplCanvas2(FigureCanvas):
+class MyMplCanvas2(FigureCanvasQTAgg):
     """
     MPL Canvas class.
     """
@@ -1418,6 +1439,11 @@ class Occam1D(QtWidgets.QDialog):
 
     def __init__(self, parent=None):
         super().__init__(parent)
+        if parent is None:
+            self.showprocesslog = print
+        else:
+            self.showprocesslog = parent.showprocesslog
+
         self.indata = {}
         self.outdata = {}
         self.data = None
@@ -1550,7 +1576,8 @@ class Occam1D(QtWidgets.QDialog):
         None.
 
         """
-        self.lbl_profnum.setText('Solution: '+str(self.hs_profnum.sliderPosition()))
+        self.lbl_profnum.setText('Solution: ' +
+                                 str(self.hs_profnum.sliderPosition()))
         self.change_band()
 
     def acceptall(self):
@@ -1749,7 +1776,7 @@ class Occam1D(QtWidgets.QDialog):
         if 'MT - EDI' in self.indata:
             self.data = copy.deepcopy(self.indata['MT - EDI'])
         else:
-            print('No EDI data')
+            self.showprocesslog('No EDI data')
             return False
 
         self.combobox1.currentIndexChanged.disconnect()
@@ -1871,7 +1898,7 @@ def tonumber(test, alttext=None):
     return int(test)
 
 
-def test():
+def testfn():
     """ main test """
     datadir = r'C:\Work\Programming\pygmi\data\MT\\'
     edi_file = datadir+r"synth02.edi"
@@ -1886,5 +1913,6 @@ def test():
     test.indata['MT - EDI'] = {'SYNTH02': mt_obj}
     test.settings()
 
+
 if __name__ == "__main__":
-    test()
+    testfn()
