@@ -31,11 +31,10 @@ from PyQt5 import QtWidgets, QtCore, QtGui
 import numpy as np
 import scipy.ndimage as ndimage
 from scipy import interpolate
-from matplotlib.backends.backend_qt5agg import FigureCanvas
-from matplotlib.backends.backend_qt5agg import NavigationToolbar2QT
+from matplotlib.backends.backend_qt5agg import FigureCanvasQTAgg
+from matplotlib.backends.backend_qt5 import NavigationToolbar2QT
 from matplotlib.figure import Figure
 from matplotlib import cm
-from matplotlib import rcParams
 from osgeo import gdal
 from osgeo import osr
 import pandas as pd
@@ -48,8 +47,6 @@ from pygmi.raster.dataprep import data_to_gdal_mem
 from pygmi.raster.iodefs import get_raster
 from pygmi.misc import frm
 
-rcParams['savefig.dpi'] = 600.
-
 
 class ProfileDisplay(QtWidgets.QWidget):
     """Widget class to call the main interface."""
@@ -57,6 +54,11 @@ class ProfileDisplay(QtWidgets.QWidget):
     def __init__(self, parent=None):
         super().__init__(parent)
 
+        if parent is None:
+            self.showprocesslog = print
+        else:
+            self.showprocesslog = parent.showprocesslog
+
         self.parent = parent
         self.lmod1 = parent.lmod1
         self.showtext = parent.showtext
@@ -76,6 +78,7 @@ class ProfileDisplay(QtWidgets.QWidget):
         self.yyy = None
         self.rxxx = None
         self.ryyy = None
+        self.cproflim = None
 
         self.mmc = MyMplCanvas(self)
         self.mpl_toolbar = MyToolbar(self)
@@ -353,6 +356,7 @@ class ProfileDisplay(QtWidgets.QWidget):
             self.hs_profnum.setHidden(False)
             self.hs_sideview.setEnabled(False)
             self.prof_dir()
+            self.cproflim = None
 #            self.sprofnum()
         else:
             self.gb_dir.setHidden(True)
@@ -391,11 +395,24 @@ class ProfileDisplay(QtWidgets.QWidget):
         if curprof is None or curprof not in self.lmod1.custprofx:
             return
 
-        x1, x2 = self.lmod1.custprofx[curprof]
-        y1, y2 = self.lmod1.custprofy[curprof]
+        x1, x2, x1a, x2a = self.lmod1.custprofx[curprof]
+        y1, y2, y1a, y2a = self.lmod1.custprofy[curprof]
         px1 = 0
         px2 = np.sqrt((x2-x1)**2+(y2-y1)**2)
 
+        px1a = np.sqrt((x1a-x1)**2+(y1a-y1)**2)
+        tmp2 = np.sqrt((x1a-x2)**2+(y1a-y2)**2)
+
+        if tmp2 > px2:
+            px1a = -px1a
+
+        px2a = np.sqrt((x2a-x1)**2+(y2a-y1)**2)
+        tmp2 = np.sqrt((x1a-x2)**2+(y1a-y2)**2)
+
+        if tmp2 > px2:
+            px2a = -px2a
+
+        self.cproflim = [[x1a, x2a], [y1a, y2a], [px1a, px2a]]
         self.lmod1.custprofx['rotate'] = [px1, px2]
         self.lmod1.custprofx['adhoc'] = [x1, x2]
         self.lmod1.custprofy['adhoc'] = [y1, y2]
@@ -907,10 +924,13 @@ class ProfileDisplay(QtWidgets.QWidget):
         y1, y2 = self.lmod1.custprofy['adhoc']
         px1, px2 = self.lmod1.custprofx['rotate']
 
-        if not(self.lmod1.xrange[0] <= x1 <= x2 <= self.lmod1.xrange[1]):
+        if not(self.lmod1.xrange[0] <= x1 <= self.lmod1.xrange[1]):
             return False
-
-        if not(self.lmod1.yrange[0] <= y1 <= y2 <= self.lmod1.yrange[1]):
+        if not(self.lmod1.xrange[0] <= x2 <= self.lmod1.xrange[1]):
+            return False
+        if not(self.lmod1.yrange[0] <= y1 <= self.lmod1.yrange[1]):
+            return False
+        if not(self.lmod1.yrange[0] <= y2 <= self.lmod1.yrange[1]):
             return False
 
         # convert units to cells
@@ -1507,7 +1527,7 @@ class ProfileDisplay(QtWidgets.QWidget):
         self.combo_overview.currentIndexChanged.connect(self.pic_overview)
 
 
-class MyMplCanvas(FigureCanvas):
+class MyMplCanvas(FigureCanvasQTAgg):
     """Matplotlib Canvas"""
 
     def __init__(self, parent=None):
@@ -1515,7 +1535,7 @@ class MyMplCanvas(FigureCanvas):
         super().__init__(fig)
 
         self.lmod1 = parent.lmod1
-        self.cbar = cm.jet
+        self.cbar = cm.get_cmap('jet')
         self.curmodel = 0
         self.mywidth = 1
         self.xold = None
@@ -1569,6 +1589,7 @@ class MyMplCanvas(FigureCanvas):
         self.lims = self.laxes.imshow(self.cbar(self.lmdata), aspect='equal',
                                       interpolation='none')
         self.lprf = self.laxes.plot([0, 1], [0, 1])
+        self.lprfc = self.laxes.plot([0, 0], 'b+')
 
         self.ims2 = self.axes.imshow(self.cbar(self.mdata), aspect='auto',
                                      interpolation='none')
@@ -1581,6 +1602,7 @@ class MyMplCanvas(FigureCanvas):
         self.lims2.format_cursor_data = lambda x: ''
 
         self.prf = self.axes.plot([0, 0])
+        self.prfc = self.axes.plot([0, 0], 'b+')
 
     def button_press(self, event):
         """
@@ -1660,7 +1682,7 @@ class MyMplCanvas(FigureCanvas):
             xmin = self.lmod1.xrange[0]
             ymin = self.lmod1.yrange[0]
 
-        if self.figure.canvas.toolbar._active is None:
+        if self.figure.canvas.toolbar.mode == '':
             vlim = curaxes.viewLim
             tmp0 = curaxes.transData.transform((vlim.x0, vlim.y0))
             tmp1 = curaxes.transData.transform((vlim.x1, vlim.y1))
@@ -1916,7 +1938,6 @@ class MyMplCanvas(FigureCanvas):
         self.laxes.xaxis.set_major_formatter(frm)
         self.laxes.yaxis.set_major_formatter(frm)
 
-
         self.lims.set_visible(True)
 
         self.figure.tight_layout()
@@ -2010,6 +2031,14 @@ class MyMplCanvas(FigureCanvas):
         self.prf[0].set_data([xrng, yrng])
         self.axes.draw_artist(self.prf[0])
 
+        cproflim = self.myparent.cproflim
+        if cproflim is not None:
+            xpnt = cproflim[2]
+            self.prfc[0].set_data([xpnt, yrng])
+
+        self.axes.draw_artist(self.prfc[0])
+
+
     def update_line_top(self):
         """
         Update the top line position.
@@ -2025,6 +2054,14 @@ class MyMplCanvas(FigureCanvas):
         self.lprf[0].set_data([xrng, yrng])
         self.laxes.draw_artist(self.lprf[0])
 
+        cproflim = self.myparent.cproflim
+        if cproflim is not None:
+            xpnt = cproflim[0]
+            ypnt = cproflim[1]
+            self.lprfc[0].set_data([xpnt, ypnt])
+
+        self.laxes.draw_artist(self.lprfc[0])
+
 # This section is just for the profile line plot
 
     def init_plot(self, xdat, dat, extent, xdat2=None, dat2=None):
@@ -2425,7 +2462,7 @@ class RangedCopy(QtWidgets.QDialog):
 class MyToolbar(NavigationToolbar2QT):
     """Custom Matplotlib toolbar."""
 
-    toolitems = NavigationToolbar2QT.toolitems
+    toolitems = copy.copy(NavigationToolbar2QT.toolitems)
     toolitems += ((None, None, None, None),
                   ('Field\nDisplay\nLimits',
                    'Axis Scale', 'Axis Scale', 'axis_scale'),
@@ -2439,7 +2476,7 @@ class MyToolbar(NavigationToolbar2QT):
 
     def __init__(self, parent=None):
         super().__init__(parent.mmc, parent)
-        self.parent = parent
+        self.pparent = parent
 
     def axis_scale(self):
         """
@@ -2450,7 +2487,7 @@ class MyToolbar(NavigationToolbar2QT):
         None.
 
         """
-        self.parent.plot_scale()
+        self.pparent.plot_scale()
 
     def b_logs(self):
         """
@@ -2461,7 +2498,7 @@ class MyToolbar(NavigationToolbar2QT):
         None.
 
         """
-        self.parent.borehole_import()
+        self.pparent.borehole_import()
 
     def mag_profile(self):
         """
@@ -2472,8 +2509,8 @@ class MyToolbar(NavigationToolbar2QT):
         None.
 
         """
-        self.parent.viewmagnetics = True
-        self.parent.update_plot()
+        self.pparent.viewmagnetics = True
+        self.pparent.update_plot()
 
     def grv_profile(self):
         """
@@ -2484,8 +2521,8 @@ class MyToolbar(NavigationToolbar2QT):
         None.
 
         """
-        self.parent.viewmagnetics = False
-        self.parent.update_plot()
+        self.pparent.viewmagnetics = False
+        self.pparent.update_plot()
 
 
 class GaugeWidget(QtWidgets.QDial):
@@ -2535,6 +2572,10 @@ class ImportPicture(QtWidgets.QDialog):
     def __init__(self, parent=None):
         super().__init__(parent)
 
+        if parent is None:
+            self.showprocesslog = print
+        else:
+            self.showprocesslog = parent.showprocesslog
         self.parent = parent
         self.lmod = self.parent.lmod1
 
@@ -2759,18 +2800,23 @@ class ImportPicture(QtWidgets.QDialog):
         while curline in self.lmod.custprofx:
             curline += 1
 
-        self.lmod.custprofx[curline] = [x1, x2]
-        self.lmod.custprofy[curline] = [y1, y2]
+        x1a = self.dsb_x1.value()
+        x2a = self.dsb_x2.value()
+        y1a = self.dsb_y1.value()
+        y2a = self.dsb_y2.value()
+
+        self.lmod.custprofx[curline] = [x1, x2, x1a, x2a]
+        self.lmod.custprofy[curline] = [y1, y2, y1a, y2a]
         self.lmod.profpics[curline] = None
 
         imptext = self.importfile.text()
         if imptext != '':
-            x1a = self.dsb_x1.value()
-            x2a = self.dsb_x2.value()
-            y1a = self.dsb_y1.value()
-            y2a = self.dsb_y2.value()
+            # x1a = self.dsb_x1.value()
+            # x2a = self.dsb_x2.value()
+            # y1a = self.dsb_y1.value()
+            # y2a = self.dsb_y2.value()
 
-            dat = get_raster(imptext)
+            dat = get_raster(imptext, showprocesslog=self.showprocesslog)
 
             if dat is None:
                 QtWidgets.QMessageBox.warning(self.parent, 'Error',
