@@ -35,7 +35,6 @@ import pandas as pd
 from PIL import Image, ImageDraw
 import scipy.ndimage as ndimage
 from scipy.signal import tukey
-import scipy.interpolate as si
 import pygmi.menu_default as menu_default
 from pygmi.raster.datatypes import Data
 
@@ -73,6 +72,10 @@ class DataCut():
         self.parent = parent
         self.indata = {}
         self.outdata = {}
+        if parent is None:
+            self.showprocesslog = print
+        else:
+            self.showprocesslog = parent.showprocesslog
 
     def settings(self, nodialog=False):
         """
@@ -87,7 +90,7 @@ class DataCut():
         if 'Raster' in self.indata:
             data = copy.deepcopy(self.indata['Raster'])
         else:
-            print('No raster data')
+            self.showprocesslog('No raster data')
             return False
 
         nodialog = False
@@ -168,11 +171,16 @@ class DataMerge(QtWidgets.QDialog):
 
     def __init__(self, parent=None):
         super().__init__(parent)
+        if parent is None:
+            self.showprocesslog = print
+        else:
+            self.showprocesslog = parent.showprocesslog
 
         self.indata = {}
         self.outdata = {}
         self.parent = parent
         self.dxy = None
+        self.piter = parent.pbar.iter
 
         self.dsb_dxy = QtWidgets.QDoubleSpinBox()
         self.label_rows = QtWidgets.QLabel('Rows: 0')
@@ -320,46 +328,7 @@ class DataMerge(QtWidgets.QDialog):
         """
         dxy = self.dsb_dxy.value()
         self.dxy = dxy
-        data = self.indata['Raster'][0]
-        orig_wkt = data.wkt
-
-        xmin0, xmax0, ymin0, ymax0 = data.extent
-
-        for data in self.indata['Raster']:
-            xmin, xmax, ymin, ymax = data.extent
-            xmin = min(xmin, xmin0)
-            xmax = max(xmax, xmax0)
-            ymin = min(ymin, ymin0)
-            ymax = max(ymax, ymax0)
-
-        cols = int((xmax - xmin)/dxy)
-        rows = int((ymax - ymin)/dxy)
-        gtr = (xmin, dxy, 0.0, ymax, 0.0, -dxy)
-
-        if cols == 0 or rows == 0:
-            print('Your rows or cols are zero. Your input projection may be '
-                  'wrong')
-            return
-
-        dat = []
-        for data in self.indata['Raster']:
-            doffset = 0.0
-            if data.data.min() <= 0:
-                doffset = data.data.min()-1.
-                data.data = data.data - doffset
-            gtr0 = data.get_gtr()
-
-            drows, dcols = data.data.shape
-            src = data_to_gdal_mem(data, gtr0, orig_wkt, dcols, drows)
-            dest = data_to_gdal_mem(data, gtr, orig_wkt, cols, rows, True)
-
-            gdal.ReprojectImage(src, dest, orig_wkt, orig_wkt,
-                                gdal.GRA_Bilinear)
-
-            dat.append(gdal_to_dat(dest, data.dataid))
-            dat[-1].data = dat[-1].data + doffset
-            data.data = data.data + doffset
-
+        dat = merge(self.indata['Raster'], self.piter, dxy)
         self.outdata['Raster'] = dat
 
 
@@ -381,6 +350,10 @@ class DataReproj(QtWidgets.QDialog):
 
     def __init__(self, parent=None):
         super().__init__(parent)
+        if parent is None:
+            self.showprocesslog = print
+        else:
+            self.showprocesslog = parent.showprocesslog
 
         self.indata = {}
         self.outdata = {}
@@ -439,7 +412,7 @@ class DataReproj(QtWidgets.QDialog):
 
         """
         if self.in_proj.wkt == 'Unknown' or self.out_proj.wkt == 'Unknown':
-            print('Could not reproject')
+            self.showprocesslog('Could not reproject')
             return
 
 # Input stuff
@@ -494,8 +467,8 @@ class DataReproj(QtWidgets.QDialog):
             rows = round((maxy - miny)/newdim)
 
             if cols == 0 or rows == 0:
-                print('Your rows or cols are zero. Your input projection may '
-                      'be wrong')
+                self.showprocesslog('Your rows or cols are zero. '
+                                    'Your input projection may be wrong')
                 return
 
 # top left x, w-e pixel size, rotation, top left y, rotation, n-s pixel size
@@ -621,6 +594,10 @@ class GetProf():
         self.parent = parent
         self.indata = {}
         self.outdata = {}
+        if parent is None:
+            self.showprocesslog = print
+        else:
+            self.showprocesslog = parent.showprocesslog
 
     def settings(self, nodialog=False):
         """
@@ -635,7 +612,7 @@ class GetProf():
         if 'Raster' in self.indata:
             data = copy.deepcopy(self.indata['Raster'])
         else:
-            print('No raster data')
+            self.showprocesslog('No raster data')
             return False
 
         ext = 'Shape file (*.shp)'
@@ -661,7 +638,7 @@ class GetProf():
         lyr = shapef.GetLayer()
         line = lyr.GetNextFeature()
         if lyr.GetGeomType() is not ogr.wkbLineString:
-            print('You need lines in that shape file')
+            self.showprocesslog('You need lines in that shape file')
             return False
 
         data = merge(data)
@@ -843,6 +820,10 @@ class Metadata(QtWidgets.QDialog):
 
     def __init__(self, parent=None):
         super().__init__(parent)
+        if parent is None:
+            self.showprocesslog = print
+        else:
+            self.showprocesslog = parent.showprocesslog
 
         self.indata = {}
         self.outdata = {}
@@ -1024,7 +1005,7 @@ class Metadata(QtWidgets.QDialog):
             odata.extent = (left, right, bottom, top)
 
         except ValueError:
-            print('Value error - abandoning changes')
+            self.showprocesslog('Value error - abandoning changes')
 
         indx = self.combobox_bandid.currentIndex()
         txt = self.combobox_bandid.itemText(indx)
@@ -1459,30 +1440,68 @@ def fftprep(data):
     cdiff = nc//2
     rdiff = nr//2
 
-    # Section to pad data
+    # # Section to pad data
 
-    nr, nc = data.data.shape
+    # nr, nc = data.data.shape
 
-    z1 = np.zeros((nr+2*rdiff, nc+2*cdiff))-999
+    # z1 = np.zeros((nr+2*rdiff, nc+2*cdiff))-999
+    # x1, y1 = np.mgrid[0: nr+2*rdiff, 0: nc+2*cdiff]
+    # z1[rdiff:-rdiff, cdiff:-cdiff] = ndat.filled(-999)
+
+    # z1[0] = 0
+    # z1[-1] = 0
+    # z1[:, 0] = 0
+    # z1[:, -1] = 0
+
+    # x = x1.flatten()
+    # y = y1.flatten()
+    # z = z1.flatten()
+
+    # x = x[z != -999]
+    # y = y[z != -999]
+    # z = z[z != -999]
+
+    # points = np.transpose([x, y])
+
+    # zfin = si.griddata(points, z, (x1, y1), method='nearest')
+
+    z1 = np.zeros((nr+2*rdiff, nc+2*cdiff))+np.nan
     x1, y1 = np.mgrid[0: nr+2*rdiff, 0: nc+2*cdiff]
-    z1[rdiff:-rdiff, cdiff:-cdiff] = ndat.filled(-999)
+    z1[rdiff:-rdiff, cdiff:-cdiff] = ndat.filled(np.nan)
 
-    z1[0] = 0
-    z1[-1] = 0
-    z1[:, 0] = 0
-    z1[:, -1] = 0
+    for j in range(2):
+        z1[0] = 0
+        z1[-1] = 0
+        z1[:, 0] = 0
+        z1[:, -1] = 0
 
-    x = x1.flatten()
-    y = y1.flatten()
-    z = z1.flatten()
+        vert = np.zeros_like(z1)
+        hori = np.zeros_like(z1)
 
-    x = x[z != -999]
-    y = y[z != -999]
-    z = z[z != -999]
+        for i in range(z1.shape[0]):
+            mask = ~np.isnan(z1[i])
+            y = y1[i][mask]
+            z = z1[i][mask]
+            hori[i] = np.interp(y1[i], y, z)
 
-    points = np.transpose([x, y])
+        for i in range(z1.shape[1]):
+            mask = ~np.isnan(z1[:, i])
+            x = x1[:, i][mask]
+            z = z1[:, i][mask]
 
-    zfin = si.griddata(points, z, (x1, y1), method='linear')
+            vert[:, i] = np.interp(x1[:, i], x, z)
+
+        hori[hori == 0] = np.nan
+        vert[vert == 0] = np.nan
+
+        hv = hori.copy()
+        hv[np.isnan(hori)] = vert[np.isnan(hori)]
+        hv[~np.isnan(hv)] = np.nanmean([hori[~np.isnan(hv)],
+                                        vert[~np.isnan(hv)]], 0)
+
+        z1[np.isnan(z1)] = hv[np.isnan(z1)]
+
+    zfin = z1
 
     nr, nc = zfin.shape
     zfin *= tukey(nc)
@@ -1572,7 +1591,11 @@ def fftcont(data, h):
     xdim = data.xdim
     ydim = data.ydim
 
+    # self.showprocesslog('Preparing for FFT...')
     ndat, rdiff, cdiff, datamedian = fftprep(data)
+
+    # self.showprocesslog('Continuing data...')
+
     fftmod = np.fft.fft2(ndat)
 
     ny, nx = fftmod.shape
@@ -2032,7 +2055,58 @@ def getepsgcodes():
     return pcodes
 
 
-def merge(dat):
+# def merge(dat, piter=None):
+#     """
+#     Merge datasets found in a single PyGMI data object.
+
+#     The aim is to ensure that all datasets have the same number of rows and
+#     columns.
+
+#     Parameters
+#     ----------
+#     dat : PyGMI Data
+#         data object which stores datasets
+
+#     Returns
+#     -------
+#     out : PyGMI Data
+#         data object which stores datasets
+#     """
+#     if piter is None:
+#         piter = iter
+
+#     if dat[0].isrgb:
+#         return dat
+
+#     needsmerge = False
+#     rows, cols = dat[0].data.shape
+#     for i in dat:
+#         irows, icols = i.data.shape
+#         if irows != rows or icols != cols:
+#             needsmerge = True
+
+#     if needsmerge is False:
+#         dat = check_dataid(dat)
+#         return dat
+
+#     self.showprocesslog('Merging data...')
+#     mrg = DataMerge()
+#     mrg.indata['Raster'] = dat
+#     data = dat[0]
+#     dxy0 = min(data.xdim, data.ydim)
+#     for data in dat:
+#         dxy = min(dxy0, data.xdim, data.ydim)
+
+#     mrg.dsb_dxy.setValue(dxy)
+#     mrg.acceptall()
+#     out = mrg.outdata['Raster']
+
+#     out = check_dataid(out)
+
+#     return out
+
+
+def merge(dat, piter=None, dxy=None):
     """
     Merge datasets found in a single PyGMI data object.
 
@@ -2049,33 +2123,75 @@ def merge(dat):
     out : PyGMI Data
         data object which stores datasets
     """
+
+    if piter is None:
+        piter = iter
+
     if dat[0].isrgb:
         return dat
 
     needsmerge = False
     rows, cols = dat[0].data.shape
+
     for i in dat:
         irows, icols = i.data.shape
         if irows != rows or icols != cols:
             needsmerge = True
+        if dxy is not None and (i.xdim != dxy or i.ydim != dxy):
+            needsmerge = True
 
     if needsmerge is False:
         dat = check_dataid(dat)
         return dat
 
-    print('Merging data...')
-    mrg = DataMerge()
-    mrg.indata['Raster'] = dat
+    # self.showprocesslog('Merging data...')
+
     data = dat[0]
     dxy0 = min(data.xdim, data.ydim)
+    if dxy is None:
+        for data in dat:
+            dxy = min(dxy0, data.xdim, data.ydim)
+
+    orig_wkt = data.wkt
+    xmin0, xmax0, ymin0, ymax0 = data.extent
+
     for data in dat:
-        dxy = min(dxy0, data.xdim, data.ydim)
+        xmin, xmax, ymin, ymax = data.extent
+        xmin = min(xmin, xmin0)
+        xmax = max(xmax, xmax0)
+        ymin = min(ymin, ymin0)
+        ymax = max(ymax, ymax0)
 
-    mrg.dsb_dxy.setValue(dxy)
-    mrg.acceptall()
-    out = mrg.outdata['Raster']
+    cols = int((xmax - xmin)/dxy)
+    rows = int((ymax - ymin)/dxy)
+    gtr = (xmin, dxy, 0.0, ymax, 0.0, -dxy)
 
-    out = check_dataid(out)
+    if cols == 0 or rows == 0:
+        print('Your rows or cols are zero. Your input projection may be wrong')
+        return None
+
+    dat2 = []
+    for data in piter(dat):
+        doffset = 0.0
+        data.data.set_fill_value(data.nullvalue)
+        data.data = np.ma.array(data.data.filled(), mask=data.data.mask)
+        if data.data.min() <= 0:
+            doffset = data.data.min()-1.
+            data.data = data.data - doffset
+        gtr0 = data.get_gtr()
+
+        drows, dcols = data.data.shape
+        src = data_to_gdal_mem(data, gtr0, orig_wkt, dcols, drows)
+        dest = data_to_gdal_mem(data, gtr, orig_wkt, cols, rows, True)
+
+        gdal.ReprojectImage(src, dest, orig_wkt, orig_wkt,
+                            gdal.GRA_Bilinear)
+
+        dat2.append(gdal_to_dat(dest, data.dataid))
+        dat2[-1].data = dat2[-1].data + doffset
+        data.data = data.data + doffset
+
+    out = check_dataid(dat2)
 
     return out
 
@@ -2159,11 +2275,11 @@ def testrtp():
 # Calculate the field
 
     magval = lmod.griddata['Calculated Magnetics'].data
-    plt.imshow(magval, cmap=cm.jet)
+    plt.imshow(magval, cmap=cm.get_cmap('jet'))
     plt.show()
 
     dat2 = rtp(lmod.griddata['Calculated Magnetics'], finc, fdec)
-    plt.imshow(dat2.data, cmap=cm.jet)
+    plt.imshow(dat2.data, cmap=cm.get_cmap('jet'))
     plt.show()
 
 
@@ -2225,10 +2341,83 @@ def testdown():
 
 #    plt.plot(z[50], 'r-.')
     plt.plot(downz0.data[50], 'r.')
-    plt.plot(zdown[50], 'b')
-    plt.plot(zdownn[50], 'k')
+    # plt.plot(zdown.data[50], 'b')
+    plt.plot(zdownn.data[50], 'k')
     plt.show()
 
 
+def testgrid():
+    """
+    Test.
+
+    Returns
+    -------
+    None.
+
+    """
+    from pygmi.raster.iodefs import get_raster
+    from pygmi.misc import PTime
+    import matplotlib.pyplot as plt
+
+    ttt = PTime()
+
+    ifile = r'C:\Work\Workdata\upward\EB_MTEF_Mag_IGRFrem.ers'
+    dat = get_raster(ifile)[0]
+
+    # z = dat.data
+    nr, nc = dat.data.shape
+
+    datamedian = np.ma.median(dat.data)
+    ndat = dat.data - datamedian
+
+    cdiff = nc//2
+    rdiff = nr//2
+
+    # Section to pad data
+
+    z1 = np.zeros((nr+2*rdiff, nc+2*cdiff))+np.nan
+    x1, y1 = np.mgrid[0: nr+2*rdiff, 0: nc+2*cdiff]
+    z1[rdiff:-rdiff, cdiff:-cdiff] = ndat.filled(np.nan)
+
+    ttt.since_last_call('Preparation')
+
+    for j in range(2):
+        z1[0] = 0
+        z1[-1] = 0
+        z1[:, 0] = 0
+        z1[:, -1] = 0
+
+        vert = np.zeros_like(z1)
+        hori = np.zeros_like(z1)
+
+        for i in range(z1.shape[0]):
+            mask = ~np.isnan(z1[i])
+            y = y1[i][mask]
+            z = z1[i][mask]
+            hori[i] = np.interp(y1[i], y, z)
+
+        for i in range(z1.shape[1]):
+            mask = ~np.isnan(z1[:, i])
+            x = x1[:, i][mask]
+            z = z1[:, i][mask]
+
+            vert[:, i] = np.interp(x1[:, i], x, z)
+
+        hori[hori == 0] = np.nan
+        vert[vert == 0] = np.nan
+
+        hv = hori.copy()
+        hv[np.isnan(hori)] = vert[np.isnan(hori)]
+        hv[~np.isnan(hv)] = np.nanmean([hori[~np.isnan(hv)],
+                                        vert[~np.isnan(hv)]], 0)
+
+        z1[np.isnan(z1)] = hv[np.isnan(z1)]
+
+    plt.imshow(z1)
+    plt.show()
+
+    ttt.since_last_call('Griddata, nearest')
+
+
 if __name__ == "__main__":
     testdown()
