@@ -153,6 +153,10 @@ class ImportData():
         self.indata = {}
         self.outdata = {}
         self.filt = ''
+        if parent is None:
+            self.showprocesslog = print
+        else:
+            self.showprocesslog = parent.showprocesslog
 
     def settings(self, nodialog=False):
         """
@@ -167,10 +171,11 @@ class ImportData():
 
         piter = None
         if not nodialog:
-            piter = self.parent.pbar.iter
+            if self.parent is not None:
+                piter = self.parent.pbar.iter
             ext = ('Common formats (*.ers *.hdr *.tif *.sdat *.img *.pix *.bil);;'
                    'ERMapper (*.ers);;'
-                   'ENVI (*.hdr);;'
+                   'ENVI (*.hdr *.dat *.img *.raw);;'
                    'ERDAS Imagine (*.img);;'
                    'PCI Geomatics Database File (*.pix);;'
                    'GeoTiff (*.tif);;'
@@ -208,9 +213,11 @@ class ImportData():
                                                         nval)
             if not ok:
                 nval = 0.0
-            dat = get_raster(self.ifile, nval, piter=piter)
+            dat = get_raster(self.ifile, nval, piter=piter,
+                             showprocesslog=self.showprocesslog)
         else:
-            dat = get_raster(self.ifile, piter=piter)
+            dat = get_raster(self.ifile, piter=piter,
+                             showprocesslog=self.showprocesslog)
 
         if dat is None:
             if self.filt == 'Surfer grid (v.6) (*.grd)':
@@ -319,6 +326,10 @@ class ImportRGBData():
         self.parent = parent
         self.indata = {}
         self.outdata = {}
+        if parent is None:
+            self.showprocesslog = print
+        else:
+            self.showprocesslog = parent.showprocesslog
 
     def settings(self, nodialog=False):
         """
@@ -340,7 +351,7 @@ class ImportRGBData():
 
         os.chdir(os.path.dirname(self.ifile))
 
-        dat = get_raster(self.ifile)
+        dat = get_raster(self.ifile, showprocesslog=self.showprocesslog)
 
         if dat is None:
             QtWidgets.QMessageBox.warning(self.parent, 'Error',
@@ -356,8 +367,12 @@ class ImportRGBData():
 
         output_type = 'Raster'
 
-        dat2 = np.ma.transpose([dat[0].data.T, dat[1].data.T,
-                                dat[2].data.T])
+        if len(dat) == 4:
+            dat2 = np.ma.transpose([dat[0].data.T, dat[1].data.T,
+                                    dat[2].data.T, dat[3].data.T])
+        else:
+            dat2 = np.ma.transpose([dat[0].data.T, dat[1].data.T,
+                                    dat[2].data.T])
         dat = [dat[0]]
         dat[0].data = dat2
         dat[0].isrgb = True
@@ -409,6 +424,7 @@ class ImportRGBData():
 
         return projdata
 
+
 def clusterprep(dat):
     """
     Prepare Cluster data from raster data.
@@ -524,7 +540,7 @@ def get_ascii(ifile):
     return dat
 
 
-def get_raster(ifile, nval=None, piter=None):
+def get_raster(ifile, nval=None, piter=None, showprocesslog=print):
     """
     This function loads a raster dataset off the disk using the GDAL
     libraries. It returns the data in a PyGMI data object.
@@ -546,7 +562,7 @@ def get_raster(ifile, nval=None, piter=None):
         piter = iter
 
     dat = []
-    bname = ifile.split('/')[-1].rpartition('.')[0]+': '
+    bname = ifile.split('/')[-1].rpartition('.')[0]
     ifile = ifile[:]
     ext = ifile[-3:]
     custom_wkt = None
@@ -597,12 +613,12 @@ def get_raster(ifile, nval=None, piter=None):
         if dat[i].data.dtype.kind == 'i':
             if nval is None:
                 nval = 999999
-                print('Adjusting null value to '+str(nval))
+                showprocesslog('Adjusting null value to '+str(nval))
             nval = int(nval)
         elif dat[i].data.dtype.kind == 'u':
             if nval is None:
                 nval = 0
-                print('Adjusting null value to '+str(nval))
+                showprocesslog('Adjusting null value to '+str(nval))
             nval = int(nval)
         else:
             if nval is None:
@@ -610,10 +626,10 @@ def get_raster(ifile, nval=None, piter=None):
             nval = float(nval)
             if nval not in dat[i].data and np.isclose(dat[i].data.min(), nval):
                 nval = dat[i].data.min()
-                print('Adjusting null value to '+str(nval))
+                showprocesslog('Adjusting null value to '+str(nval))
             if nval not in dat[i].data and np.isclose(dat[i].data.max(), nval):
                 nval = dat[i].data.max()
-                print('Adjusting null value to '+str(nval))
+                showprocesslog('Adjusting null value to '+str(nval))
 
         if ext == 'ers' and nval == -1.0e+32:
             dat[i].data[np.ma.less_equal(dat[i].data, nval)] = -1.0e+32
@@ -628,8 +644,9 @@ def get_raster(ifile, nval=None, piter=None):
                                 + np.ma.getmaskarray(dat[i].data))
 
         dat[i].extent_from_gtr(gtr)
+
         if bandid == '':
-            bandid = bname+str(i+1)
+            bandid = 'Band '+str(i+1)+' '+bname
         dat[i].dataid = bandid
         if bandid[-1] == ')':
             dat[i].units = bandid[bandid.rfind('(')+1:-1]
@@ -880,10 +897,19 @@ class ExportData():
 
     def __init__(self, parent=None):
         self.ifile = ''
+
+        if parent is None:
+            self.piter = iter
+        else:
+            self.piter = parent.pbar.iter
         self.pbar = None
         self.parent = parent
         self.indata = {}
         self.outdata = {}
+        if parent is None:
+            self.showprocesslog = print
+        else:
+            self.showprocesslog = parent.showprocesslog
 
     def run(self):
         """
@@ -915,7 +941,7 @@ class ExportData():
         elif 'Raster' in self.indata:
             data = self.indata['Raster']
         else:
-            print('No raster data')
+            self.showprocesslog('No raster data')
             self.parent.process_is_active(False)
             return False
 
@@ -939,7 +965,7 @@ class ExportData():
 
         self.ifile = str(filename)
 
-        print('Export Data Busy...')
+        self.showprocesslog('Export Data Busy...')
 
     # Pop up save dialog box
         if filt == 'ArcInfo ASCII (*.asc)':
@@ -950,26 +976,26 @@ class ExportData():
             self.export_gxf(data)
         if filt == 'Surfer grid (v.6) (*.grd)':
             self.export_surfer(data)
-#            self.export_gdal(data, 'GSBG')
+#            self.export_gdal(data, 'GSBG', piter=self.piter)
         if filt == 'ERDAS Imagine (*.img)':
-            export_gdal(self.ifile, data, 'HFA')
+            export_gdal(self.ifile, data, 'HFA', piter=self.piter)
         if filt == 'ERMapper (*.ers)':
-            export_gdal(self.ifile, data, 'ERS')
+            export_gdal(self.ifile, data, 'ERS', piter=self.piter)
         if filt == 'SAGA binary grid (*.sdat)':
             if len(data) > 1:
                 for i, dat in enumerate(data):
                     file_out = self.get_filename(dat, 'sdat')
-                    export_gdal(file_out, [dat], 'SAGA')
+                    export_gdal(file_out, [dat], 'SAGA', piter=self.piter)
             else:
-                export_gdal(self.ifile, data, 'SAGA')
+                export_gdal(self.ifile, data, 'SAGA', piter=self.piter)
         if filt == 'GeoTiff (*.tif)':
-            export_gdal(self.ifile, data, 'GTiff')
+            export_gdal(self.ifile, data, 'GTiff', piter=self.piter)
         if filt == 'ENVI (*.hdr)':
-            export_gdal(self.ifile, data, 'ENVI')
+            export_gdal(self.ifile, data, 'ENVI', piter=self.piter)
         if filt == 'ArcGIS BIL (*.bil)':
-            export_gdal(self.ifile, data, 'EHdr')
+            export_gdal(self.ifile, data, 'EHdr', piter=self.piter)
 
-        print('Export Data Finished!')
+        self.showprocesslog('Export Data Finished!')
         self.parent.process_is_active(False)
         return True
 
@@ -988,8 +1014,9 @@ class ExportData():
 
         """
         if len(data) > 1:
-            print('Band names will be appended to the output filenames since '
-                  'you have a multiple band image')
+            self.showprocesslog('Band names will be appended to the output '
+                                'filenames since you have a multiple band '
+                                'image')
 
         file_out = self.ifile.rpartition('.')[0]+'.gxf'
         for k in data:
@@ -1053,8 +1080,9 @@ class ExportData():
 
         """
         if len(data) > 1:
-            print('Band names will be appended to the output filenames since '
-                  'you have a multiple band image')
+            self.showprocesslog('Band names will be appended to the output '
+                                'filenames since you have a multiple band '
+                                'image')
 
         file_out = self.ifile.rpartition('.')[0] + '.grd'
         for k in data:
@@ -1097,8 +1125,9 @@ class ExportData():
 
         """
         if len(data) > 1:
-            print('Band names will be appended to the output filenames since '
-                  'you have a multiple band image')
+            self.showprocesslog('Band names will be appended to the output '
+                                'filenames since you have a multiple band '
+                                'image')
 
         file_out = self.ifile.rpartition('.')[0]+'.asc'
         for k in data:
@@ -1143,8 +1172,9 @@ class ExportData():
 
         """
         if len(data) > 1:
-            print('Band names will be appended to the output filenames since '
-                  'you have a multiple band image')
+            self.showprocesslog('Band names will be appended to the output '
+                                'filenames since you have a multiple band '
+                                'image')
 
         file_out = self.ifile.rpartition('.')[0]+'.xyz'
         for k in data:
@@ -1190,7 +1220,7 @@ class ExportData():
         return file_out
 
 
-def export_gdal(ifile, dat, drv):
+def export_gdal(ifile, dat, drv, envimeta='', piter=None):
     """
     Export to GDAL format
 
@@ -1207,13 +1237,25 @@ def export_gdal(ifile, dat, drv):
 
     """
 
-    data = merge(dat)
+    if piter is None:
+        piter = iter
+
+    if isinstance(dat, dict):
+        dat2 = []
+        for i in dat:
+            dat2.append(dat[i])
+    else:
+        dat2 = dat
+
+    data = merge(dat2)
 
     driver = gdal.GetDriverByName(drv)
     dtype = data[0].data.dtype
 
     if dtype == np.uint8:
         fmt = gdal.GDT_Byte
+    elif dtype == np.uint16:
+        fmt = gdal.GDT_UInt16
     elif dtype == np.int32:
         fmt = gdal.GDT_Int32
     elif dtype == np.float64:
@@ -1238,8 +1280,12 @@ def export_gdal(ifile, dat, drv):
         data[0].nullvalue = -99999.0
     elif drv == 'HFA':
         tmpfile = tmp[0]+'.img'
-    else:  # ENVI and ER Mapper
+    elif drv == 'ENVI':
+        tmpfile = tmp[0]+'.dat'
+    elif drv == 'ERS':  # ER Mapper
         tmpfile = tmp[0]
+    else:
+        tmpfile = ifile
 
     drows, dcols = data[0].data.shape
     if drv == 'GTiff':
@@ -1268,7 +1314,9 @@ def export_gdal(ifile, dat, drv):
 
     out.SetProjection(data[0].wkt)
 
-    for i, datai in enumerate(data):
+    numbands = len(data)
+    for i in piter(range(numbands)):
+        datai = data[i]
         rtmp = out.GetRasterBand(i+1)
         rtmp.SetDescription(datai.dataid)
         rtmp.SetMetadataItem('BandName', datai.dataid)
@@ -1289,5 +1337,6 @@ def export_gdal(ifile, dat, drv):
 
     out = None  # Close File
     if drv == 'ENVI':
-        with open(tmpfile+'.hdr', 'a') as myfile:
-            myfile.write('data ignore value = ' + str(data[0].nullvalue))
+        with open(tmpfile[:-4]+'.hdr', 'a') as myfile:
+            myfile.write('data ignore value = ' + str(data[0].nullvalue)+'\n')
+            myfile.write(envimeta)
