@@ -167,6 +167,10 @@ class ImportData():
         self.indata = {}
         self.outdata = {}
         self.extscene = extscene
+        if parent is None:
+            self.showprocesslog = print
+        else:
+            self.showprocesslog = parent.showprocesslog
 
     def settings(self, nodialog=False):
         """
@@ -182,7 +186,7 @@ class ImportData():
         piter = self.parent.pbar.iter
 
         if self.extscene is None:
-            return
+            return False
 
         if not nodialog:
             self.ifile, self.filt = QtWidgets.QFileDialog.getOpenFileName(
@@ -190,7 +194,7 @@ class ImportData():
             if self.ifile == '':
                 return False
         os.chdir(os.path.dirname(self.ifile))
-        dat = get_data(self.ifile, piter)
+        dat = get_data(self.ifile, piter, self.showprocesslog)
 
         if dat is None:
             if self.filt == 'hdf (*.hdf *.h5)':
@@ -398,6 +402,10 @@ class ImportSentinel5P(QtWidgets.QDialog):
 
     def __init__(self, parent=None):
         super().__init__(parent)
+        if parent is None:
+            self.showprocesslog = print
+        else:
+            self.showprocesslog = parent.showprocesslog
 
         self.pbar = None  # self.parent.pbar
         self.parent = parent
@@ -506,7 +514,7 @@ class ImportSentinel5P(QtWidgets.QDialog):
             _ = float(self.lonmax.text())
             _ = float(self.latmax.text())
         except ValueError:
-            print('Value error - abandoning import')
+            self.showprocesslog('Value error - abandoning import')
             return False
 
         gdf = self.get_5P_data(meta)
@@ -572,8 +580,8 @@ class ImportSentinel5P(QtWidgets.QDialog):
 
         dataset = gdal.Open(self.ifile, gdal.GA_ReadOnly)
         if dataset is None:
-            print('Problem! Unable to import')
-            print(os.path.basename(self.ifile))
+            self.showprocesslog('Problem! Unable to import')
+            self.showprocesslog(os.path.basename(self.ifile))
             return None
 
         subdata = dataset.GetSubDatasets()
@@ -633,7 +641,7 @@ class ImportSentinel5P(QtWidgets.QDialog):
         del meta['longitude']
 
         if lats is None:
-            print('No Latitudes in dataset')
+            self.showprocesslog('No Latitudes in dataset')
             return None
 
         lats = lats.flatten()
@@ -668,7 +676,7 @@ class ImportSentinel5P(QtWidgets.QDialog):
         dat1 = dat1[dat1 != 9.96921e+36]
 
         if dat1.size == 0:
-            print(idfile, 'is empty.')
+            self.showprocesslog(idfile, 'is empty.')
             return None
 
         df = pd.DataFrame({'lon': pnts1[:, 0], 'lat': pnts1[:, 1]})
@@ -776,7 +784,7 @@ class ImportShapeData():
         return projdata
 
 
-def calculate_toa(dat):
+def calculate_toa(dat, showprocesslog=print):
     """
     Top of atmosphere correction. Includes VNIR, SWIR and TIR bands.
 
@@ -791,7 +799,7 @@ def calculate_toa(dat):
         PyGMI raster dataset
     """
 
-    print('Calculating top of atmosphere...')
+    showprocesslog('Calculating top of atmosphere...')
 
     datanew = {}
     for datai in dat:
@@ -823,7 +831,7 @@ def calculate_toa(dat):
     return out
 
 
-def get_data(ifile, piter=None):
+def get_data(ifile, piter=None, showprocesslog=print):
     """
     This function loads a raster dataset off the disk using the GDAL
     libraries. It returns the data in a PyGMI data object.
@@ -841,23 +849,25 @@ def get_data(ifile, piter=None):
     ifile = ifile[:]
     bfile = os.path.basename(ifile)
 
-    print('Importing', bfile)
+    showprocesslog('Importing', bfile)
 
     if 'AST_' in bfile and 'hdf' in bfile.lower():
         dat = get_aster_hdf(ifile, piter)
     elif 'AST_' in bfile and 'zip' in bfile.lower():
-        dat = get_aster_zip(ifile, piter)
+        dat = get_aster_zip(ifile, piter, showprocesslog)
     elif bfile[:4] in ['LT04', 'LT05', 'LE07', 'LC08', 'LM05']:
-        dat = get_landsat(ifile, piter)
+        dat = get_landsat(ifile, piter, showprocesslog)
     elif '.xml' in bfile and '.SAFE' in ifile:
-        dat = get_sentinel2(ifile, piter)
+        dat = get_sentinel2(ifile, piter, showprocesslog)
+    elif 'MOD' in bfile and 'hdf' in bfile.lower() and '.006.' in bfile:
+        dat = get_modisv6(ifile, piter)
     else:
         dat = None
 
     return dat
 
 
-def get_modis(ifile):
+def get_modis(ifile, showprocesslog=print):
     """
     Gets MODIS data
 
@@ -945,7 +955,8 @@ def get_modis(ifile):
             if newx.size == 0:
                 dat[i].data = np.zeros((rows, cols)) + nval
             else:
-                tmp = quickgrid(newx, newy, newz, latsdim)
+                tmp = quickgrid(newx, newy, newz, latsdim,
+                                showprocesslog=showprocesslog)
                 mask = np.ma.getmaskarray(tmp)
                 gdat = tmp.data
                 dat[i].data = np.ma.masked_invalid(gdat[::-1])
@@ -994,7 +1005,95 @@ def get_modis(ifile):
     return dat
 
 
-def get_landsat(ifilet, piter=None):
+def get_modisv6(ifile, piter=None):
+    """
+    Gets MODIS v006 data.
+
+    Parameters
+    ----------
+    ifile : str
+        filename to import
+
+    Returns
+    -------
+    dat : PyGMI raster Data
+        dataset imported
+    """
+    dat = []
+    ifile = ifile[:]
+
+    if piter is None:
+        piter = iter
+
+    dataset = gdal.Open(ifile, gdal.GA_ReadOnly)
+    # dmeta = dataset.GetMetadata()
+
+    subdata = dataset.GetSubDatasets()
+    dataset = None
+
+    dat = []
+    nval = 0
+    for ifile2, bandid2 in subdata:
+        dataset = gdal.Open(ifile2, gdal.GA_ReadOnly)
+
+        wkt = dataset.GetProjectionRef()
+        if 'Sinusoidal' in wkt:
+            wkt = wkt.replace('PROJCS["unnamed"', 'PROJCS["Sinusoidal"')
+            wkt = wkt.replace('GEOGCS["Unknown datum based upon the custom '
+                              'spheroid"',
+                              'GEOGCS["GCS_Unknown"')
+            wkt = wkt.replace('DATUM["Not specified '
+                              '(based on custom spheroid)"',
+                              'DATUM["D_Unknown"')
+            wkt = wkt.replace('SPHEROID["Custom spheroid"',
+                              'SPHEROID["S_Unknown"')
+
+        meta = dataset.GetMetadata()
+        nval = int(meta['_FillValue'])
+        bandid = bandid2.split('] ')[1].split(' (')[0]
+
+        if 'scale_factor' in meta:
+            scale = float(meta['scale_factor'])
+        else:
+            scale = 1
+
+        if 'add_offset' in meta:
+            offset = float(meta['add_offset'])
+        else:
+            offset = 0
+
+        rtmp2 = dataset.ReadAsArray()
+        rtmp2 = rtmp2.astype(float)
+        mask = (rtmp2 == nval)
+        if nval == 32767:
+            mask = (rtmp2 > 32700)
+        rtmp2 = rtmp2*scale+offset
+
+        if mask is not None:
+            rtmp2[mask] = nval
+
+        dat.append(Data())
+        dat[-1].data = rtmp2
+        dat[-1].data = np.ma.masked_invalid(dat[-1].data)
+        dat[-1].data.mask = dat[-1].data.mask | (dat[-1].data == nval)
+        if dat[-1].data.mask.size == 1:
+            dat[-1].data.mask = (np.ma.make_mask_none(dat[-1].data.shape) +
+                                 dat[-1].data.mask)
+
+        dat[-1].extent_from_gtr(dataset.GetGeoTransform())
+        dat[-1].dataid = bandid
+        dat[-1].nullvalue = nval
+        dat[-1].wkt = wkt
+        dat[-1].filename = ifile
+        if 'units' in meta and meta['units'] != 'none':
+            dat[-1].units = '$'+meta['units']+'$'
+
+        dataset = None
+
+    return dat
+
+
+def get_landsat(ifilet, piter=None, showprocesslog=print):
     """
     Gets Landsat Data.
 
@@ -1019,20 +1118,20 @@ def get_landsat(ifilet, piter=None):
             tarnames = tar.getnames()
             ifile = next((i for i in tarnames if '_MTL.txt' in i), None)
             if ifile is None:
-                print('Could not find MTL.txt file in tar archive')
+                showprocesslog('Could not find MTL.txt file in tar archive')
                 return None
-            print('Extracting tar...')
+            showprocesslog('Extracting tar...')
             tar.extractall(idir)
             ifile = os.path.join(idir, ifile)
     elif '_MTL.txt' in ifilet:
         ifile = ifilet
     else:
-        print('Input needs to be tar.gz or _MTL.txt')
+        showprocesslog('Input needs to be tar.gz or _MTL.txt')
         return None
 
     files = glob.glob(ifile[:-7]+'*[0-9].tif')
 
-    print('Importing Landsat data...')
+    showprocesslog('Importing Landsat data...')
 
     nval = 0
     dat = []
@@ -1044,12 +1143,12 @@ def get_landsat(ifilet, piter=None):
         else:
             fext = ifile2[-5]
 
-        print('Importing Band', fext)
+        showprocesslog('Importing Band', fext)
 
         dataset = gdal.Open(ifile2, gdal.GA_ReadOnly)
 
         if dataset is None:
-            print('Problem with band '+fext)
+            showprocesslog('Problem with band '+fext)
             breakpoint()
             continue
 
@@ -1075,14 +1174,14 @@ def get_landsat(ifilet, piter=None):
         dat = None
 
     if 'tar.gz' in ifilet:
-        print('Cleaning Extracted tar files...')
+        showprocesslog('Cleaning Extracted tar files...')
         for tfile in tarnames:
             os.remove(os.path.join(os.path.dirname(ifile), tfile))
 
     return dat
 
 
-def get_sentinel2(ifile, piter=None):
+def get_sentinel2(ifile, piter=None, showprocesslog=print):
     """
     Gets Sentinel-2 Data.
 
@@ -1111,15 +1210,15 @@ def get_sentinel2(ifile, piter=None):
     dat = []
     for bfile, _ in subdata:
         dataset = gdal.Open(bfile, gdal.GA_ReadOnly)
-
+        showprocesslog('Importing '+os.path.basename(bfile))
         if dataset is None:
-            print('Problem with', ifile)
+            showprocesslog('Problem with '+ifile)
             continue
 
         for i in piter(range(dataset.RasterCount)):
             rtmp = dataset.GetRasterBand(i+1)
             bname = rtmp.GetDescription()
-            print('Importing', bname)
+            # self.showprocesslog('Importing '+bname)
 
             dat.append(Data())
             dat[-1].data = rtmp.ReadAsArray()
@@ -1127,13 +1226,15 @@ def get_sentinel2(ifile, piter=None):
             dat[-1].data.mask = dat[-1].data.mask | (dat[-1].data == nval)
             if dat[-1].data.mask.size == 1:
                 dat[-1].mask = np.ma.getmaskarray(dat[-1].data)
+            dat[-1].data = dat[-1].data.astype(float)
+            dat[-1].data = dat[-1].data / 10000.
 
             dat[-1].dataid = bname
             dat[-1].nullvalue = nval
             dat[-1].extent_from_gtr(dataset.GetGeoTransform())
             dat[-1].wkt = dataset.GetProjectionRef()
             dat[-1].filename = ifile
-            dat[-1].units = 'Reflectance x 10000'
+            dat[-1].units = 'Reflectance'
 
     if dat == []:
         dat = None
@@ -1141,7 +1242,7 @@ def get_sentinel2(ifile, piter=None):
     return dat
 
 
-def get_aster_zip(ifile, piter=None):
+def get_aster_zip(ifile, piter=None, showprocesslog=print):
     """
     Gets ASTER Data.
 
@@ -1173,7 +1274,7 @@ def get_aster_zip(ifile, piter=None):
     else:
         return None
 
-    print('Extracting zip...')
+    showprocesslog('Extracting zip...')
 
     idir = os.path.dirname(ifile)
     zfile = zipfile.ZipFile(ifile)
@@ -1191,7 +1292,7 @@ def get_aster_zip(ifile, piter=None):
         dataset = gdal.Open(os.path.join(idir, zfile), gdal.GA_ReadOnly)
 
         if dataset is None:
-            print('Problem with', zfile)
+            showprocesslog('Problem with '+zfile)
             continue
 
         dataset = gdal.AutoCreateWarpedVRT(dataset)
@@ -1213,7 +1314,7 @@ def get_aster_zip(ifile, piter=None):
 
         dataset = None
 
-    print('Cleaning Extracted zip files...')
+    showprocesslog('Cleaning Extracted zip files...')
     for zfile in zipnames:
         os.remove(os.path.join(idir, zfile))
 
@@ -1293,7 +1394,7 @@ def get_aster_hdf(ifile, piter=None):
         scalefactor = 1
         units = ''
     else:
-        return
+        return None
 
     dat = []
     nval = 0
@@ -1540,16 +1641,19 @@ def get_aster_ged_bin(ifile):
 
 def testfn():
     """Main testing routine."""
+    # from pprint import pprint
     # ifile = r'C:\Work\Workdata\ASTER\S2A_MSIL2A_20170813T080011_N0205_R035_T35JKG_20170813T082818.SAFE\MTD_MSIL2A.xml'
     # dat = get_sentinel2(ifile)
 
     # ifile = r'C:\Work\Workdata\ASTER\AST_07XT_00309042002082052_20200518021739_29313.zip'
     # dat = get_aster_zip(ifile)
 
-    ifile = r'C:\Work\Workdata\ASTER\LC081740432017101901T1-SC20180409064853.tar.gz'
-    dat = get_landsat(ifile)
+    # ifile = r'C:\Work\Workdata\ASTER\LC081740432017101901T1-SC20180409064853.tar.gz'
+    # dat = get_landsat(ifile)
 
-    breakpoint()
+    # ifile = r'C:/Work/Workdata/Remote Sensing/Modis/MOD16A2.A2013073.h20v11.006.2017101224330.hdf'
+    ifile = r'C:/Work/Workdata/Remote Sensing/Modis/MOD11A2.A2013073.h20v11.006.2016155170529.hdf'
+    dat = get_modisv6(ifile)
 
     # ifile = r'C:\Work\Workdata\ASTER\AST_05_00305282005083844_20180604061610_15573.hdf'
     # ofile = r'C:\Work\Workdata\ASTER\hope.tif'
@@ -1557,6 +1661,5 @@ def testfn():
     # export_gdal(ofile, dat, 'GTiff')
 
 
-
 if __name__ == "__main__":
     testfn()
