@@ -72,10 +72,13 @@ class MenuWidget():
         self.action_import_sentinel2.triggered.connect(self.import_sentinel2)
 
         self.action_import_sentinel5p = QtWidgets.QAction('Import Sentinel-5P')
-
         self.menu3.addAction(self.action_import_sentinel5p)
         self.action_import_sentinel5p.triggered.connect(self.import_sentinel5p)
 
+        self.action_import_modis = QtWidgets.QAction('Import MODIS v6')
+        self.menu3.addAction(self.action_import_modis)
+        self.action_import_modis.triggered.connect(self.import_modis)
+
         self.menu3.addSeparator()
 
         self.action_batch_list = QtWidgets.QAction('Create Batch List')
@@ -135,6 +138,11 @@ class MenuWidget():
         fnc = iodefs.ImportData(self.parent, 'Sentinel-2 (*.xml);;')
         self.parent.item_insert('Io', 'Import Sentinel-2', fnc)
 
+    def import_modis(self):
+        """Import MODIS data."""
+        fnc = iodefs.ImportData(self.parent, 'MODIS (*.hdf);;')
+        self.parent.item_insert('Io', 'Import MODIS v6', fnc)
+
     def import_aster(self):
         """Import ASTER HDF data."""
         fnc = iodefs.ImportData(self.parent, 'ASTER (AST*.hdf AST*.zip);;')
