@@ -35,14 +35,13 @@ from osgeo import ogr, osr
 from PyQt5 import QtWidgets, QtCore
 from scipy.spatial.distance import cdist
 from scipy.stats import linregress
-from matplotlib.backends.backend_qt5agg import FigureCanvas
+from matplotlib.backends.backend_qt5agg import FigureCanvasQTAgg
 from matplotlib.figure import Figure
-from matplotlib.backends.backend_qt5agg import NavigationToolbar2QT as \
-    NavigationToolbar
+from matplotlib.backends.backend_qt5 import NavigationToolbar2QT
 from matplotlib.patches import Ellipse
 
 
-class MyMplCanvas(FigureCanvas):
+class MyMplCanvas(FigureCanvasQTAgg):
     """
     Canvas for the actual plot.
 
@@ -240,7 +239,8 @@ class MyMplCanvas(FigureCanvas):
         ylbl : str, optional
             Y-axis label. The default is 'ML'.
         bins : int or str, optional
-            Number of bins or binning strategy. See matplotlib.pyplot.hist. The default is 'doane'.
+            Number of bins or binning strategy. See matplotlib.pyplot.hist.
+            The default is 'doane'.
         rng : tuple or None, optional
             Bin range. The default is None.
 
@@ -279,7 +279,8 @@ class MyMplCanvas(FigureCanvas):
         data1a : numpy array
             Data array.
         bins : int or str, optional
-            Number of bins or binning strategy. See matplotlib.pyplot.hist. The default is 'doane'.
+            Number of bins or binning strategy. See matplotlib.pyplot.hist.
+            The default is 'doane'.
 
         Returns
         -------
@@ -390,7 +391,8 @@ class MyMplCanvas(FigureCanvas):
             A1 = {}
             T1 = {}
             for rec in event['4']:
-                if rec.phase_id == 'IAML':
+                if (rec.quality+rec.phase_id).strip() in ['IAML', 'AML',
+                                                          'ES', 'E']:
                     if rec.amplitude is None or rec.epicentral_distance is None:
                         continue
                     ML = (np.log10(rec.amplitude) +
@@ -399,9 +401,11 @@ class MyMplCanvas(FigureCanvas):
                     A1[rec.station_name] = ML
                 if rec.travel_time_residual is not None:
                     T1[rec.station_name] = rec.travel_time_residual
-
             if A1:
-                A1mean = np.mean((list(A1.values())))
+                if np.nonzero(~np.isnan(list(A1.values())))[0].size == 0:
+                    A1mean = 0
+                else:
+                    A1mean = np.nanmean(list(A1.values()))
             for i in A1:
                 if i not in A:
                     A[i] = []
@@ -412,11 +416,11 @@ class MyMplCanvas(FigureCanvas):
                     T[i] = []
                 T[i].append(T1[i])
 
-        sname_list = list(A.keys())
-
         dmean = {}
         dstd = {}
 
+        sname_list = list(A.keys())
+
         if res != 'ML':
             A = T
 
@@ -540,7 +544,7 @@ class GraphWindow(QtWidgets.QDialog):
         vbl = QtWidgets.QVBoxLayout(self)  # self is where layout is assigned
         self.hbl = QtWidgets.QHBoxLayout()
         self.mmc = MyMplCanvas(self)
-        mpl_toolbar = NavigationToolbar(self.mmc, self.parent)
+        mpl_toolbar = NavigationToolbar2QT(self.mmc, self.parent)
 
         self.btn_saveshp = QtWidgets.QPushButton('Save Shapefile')
 
@@ -608,6 +612,10 @@ class PlotQC(GraphWindow):
         self.indata = {}
         self.parent = parent
         self.datd = None
+        if parent is None:
+            self.showprocesslog = print
+        else:
+            self.showprocesslog = parent.showprocesslog
 
     def change_band(self):
         """
@@ -634,7 +642,13 @@ class PlotQC(GraphWindow):
             self.mmc.update_hist(self.datd['1_year'], 'Year', bins=bins,
                                  rng=(bmin, bmax))
         elif i == 'Number of Stations':
-            self.mmc.update_hist(self.datd['1_number_of_stations_used'], i)
+            bins = np.unique(self.datd['1_number_of_stations_used']).size
+            bmin = np.nanmin(self.datd['1_number_of_stations_used'])+0.5
+            bmax = np.nanmax(self.datd['1_number_of_stations_used'])+1.5
+            self.mmc.update_hist(self.datd['1_number_of_stations_used'],
+                                 i, bins=bins, rng=(bmin, bmax))
+
+            # self.mmc.update_hist(self.datd['1_number_of_stations_used'], i)
         elif i == 'RMS of time residuals':
             rts = np.array(self.datd['1_rms_of_time_residuals'])
             self.mmc.update_hist(rts, i)
@@ -684,7 +698,7 @@ class PlotQC(GraphWindow):
         self.datd = import_for_plots(data)
 
         if not self.datd:
-            print('There is no compatible data in the file')
+            self.showprocesslog('There is no compatible data in the file')
             return
 
         products = ['Hour Histogram',
@@ -804,7 +818,7 @@ def import_for_plots(dat):
             continue
 
         for rectype in event:
-            if rectype in('1', 'E'):
+            if rectype in ('1', 'E'):
                 tmp = vars(event[rectype])
                 for j in tmp:
                     newkey = rectype+'_'+j
